@@ -126,8 +126,9 @@ int main(int argc, char *argv[]) {
   /* find NS */
   for (i = 0; i < int(fieldList.size()); i++) {
     vlist.at(i)->writeLock();
-    while (vlist.at(i)->update(-1) != KstObject::NO_CHANGE); // read vector
+    while (vlist.at(i)->update(-1) != KstObject::NO_CHANGE) { } // read vector
     vlist.at(i)->unlock();
+
     if (vlist.at(i)->length() > NS) {
       NS = vlist.at(i)->length();
     }
