@@ -26,39 +26,24 @@
 class DMCSource : public KstDataSource {
   public:
     DMCSource(KConfig *cfg, const QString& filename);
-
     ~DMCSource();
 
     KstObject::UpdateType update(int = -1);
 
-    int readField(double *v, const QString &field, int s, int n);
-
-    int readField(double *v, const QString &field, int s, int n, int skip, int *lastFrameRead = 0L);
-
-    bool isValidField(const QString &field) const;
-
-    int samplesPerFrame(const QString &field);
-
-    int frameCount(const QString& field = QString::null) const;
-
-    QString fileType() const;
-
-    void save(QTextStream &ts, const QString& indent = QString::null);
-
-    bool isEmpty() const;
-
-    bool supportsTimeConversions() const;
-
-    int sampleForTime(const KST::ExtDateTime& time, bool *ok = 0L);
-
-    int sampleForTime(double ms, bool *ok = 0L);
-
-    KST::ExtDateTime timeForSample(int sample, bool *ok = 0L);
-
-    // in (ms)
-    double relativeTimeForSample(int sample, bool *ok = 0L);
-
-    bool reset();
+    KstFrameSize      readFieldLarge(double *v, const QString &field, KstFrameSize s, KstFrameSize n);
+    KstFrameSize      readFieldLargeSkip(double *v, const QString &field, KstFrameSize s, KstFrameSize n, int skip, KstFrameSize *lastFrameRead = 0L);
+    bool              isValidField(const QString &field) const;
+    int               samplesPerFrame(const QString &field);
+    KstFrameSize      frameCountLarge(const QString& field = QString::null) const;
+    QString           fileType() const;
+    void              save(QTextStream &ts, const QString& indent = QString::null);
+    bool              isEmpty() const;
+    bool              supportsTimeConversions() const;
+    KstFrameSize      sampleForTimeLarge(const KST::ExtDateTime& time, bool *ok = 0L);
+    KstFrameSize      sampleForTimeLarge(double ms, bool *ok = 0L);
+    KST::ExtDateTime  timeForSampleLarge(KstFrameSize sample, bool *ok = 0L);
+    double            relativeTimeForSampleLarge(KstFrameSize sample, bool *ok = 0L); // in (ms)
+    bool              reset();
 
   private:
     KstSharedPtr<DMC::Object> _dmcObject;
@@ -67,4 +52,3 @@ class DMCSource : public KstDataSource {
 
 
 #endif
-
