@@ -262,7 +262,7 @@ int NADSource::readField(double *v, const QString& field, int s, int n) {
  *  be implemented.  If it returns -9999, use the non-skip version instead. */
 // if n > 0, read 1 SAMPLE from each of n FRAMES starting at frame s skipping by 'skip' for field into buffer v
 // if n < 0, read 1 SAMPLE from frame s for field into buffer v
-int NADSource::readField(double *v, const QString& field, int s, int n, int skip, int *lastFrameRead) {
+int NADSource::readFieldSkip(double *v, const QString& field, int s, int n, int skip, int *lastFrameRead) {
   if (skip == 0) {
     int ret = readField(v, field, s, n);
     // FIXME: deal with lastFrameRead
