@@ -129,7 +129,7 @@ int NADDirectSource::readField(double *v, const QString& field, int s, int n) {
  *  be implemented.  If it returns -9999, use the non-skip version instead. */
 // if n > 0, read 1 SAMPLE from each of n FRAMES starting at frame s skipping by 'skip' for field into buffer v
 // if n < 0, read 1 SAMPLE from frame s for field into buffer v
-int NADDirectSource::readField(double *v, const QString& field, int s, int n, int skip, int *lastFrameRead) {
+int NADDirectSource::readFieldSkip(double *v, const QString& field, int s, int n, int skip, int *lastFrameRead) {
   kstdDebug() << "NAD::readField(" << field << ", s=" + QString::number(s) + ", n=" + QString::number(n) + ", skip=" + QString::number(skip) + ")" << endl;
   if (lastFrameRead) *lastFrameRead = -1;
 
