@@ -33,7 +33,7 @@ class PlanckSource : public KstDataSource {
 
     int readField(double *v, const QString &field, int s, int n);
 
-    int readField(double *v, const QString &field, int s, int n, int skip, int *lastFrameRead = 0L);
+    int readFieldSkip(double *v, const QString &field, int s, int n, int skip, int *lastFrameRead = 0L);
 
     bool isValidField(const QString &field) const;
 
