@@ -19,6 +19,7 @@
 #include "planckIDEFconfig.h"
 
 #include <ctype.h>
+#include <math.h>
 #include <stdlib.h>
 
 #include <qcheckbox.h>
@@ -36,6 +37,9 @@
 
 #include "kststring.h"
 
+#define IDEF_COLUMN_DATA 1
+#define IDEF_COLUMN_FLAG 2
+
 class PLANCKIDEFSource::Config {
   public:
     Config() {
@@ -47,18 +51,30 @@ class PLANCKIDEFSource::Config {
 
       cfg->setGroup("PlanckIDEF General");
       _checkFilename = cfg->readBoolEntry("Check Filename", true);
+      _checkBadData = cfg->readBoolEntry("Check Bad Data", false);
+      _fillMissingData = cfg->readBoolEntry("Fill Missing Data", false);
     }
 
     bool _checkFilename;
+    bool _checkBadData;
+    bool _fillMissingData;
 
     void save(QTextStream& str, const QString& indent) {
       if (_checkFilename) {
-        str << indent << "checkfilename=\"" << _checkFilename << "\"/>";
+        str << indent << "<checkfilename/>" << endl;
+      }
+      if (_checkBadData) {
+        str << indent << "<checkbaddata/>" << endl;
+      }
+      if (_fillMissingData) {
+        str << indent << "<fillmissingdata/>" << endl;
       }
     }
 
     void load(const QDomElement& e) {
       _checkFilename = false;
+      _checkBadData = false;
+      _fillMissingData = false;
 
       QDomNode n = e.firstChild();
       while (!n.isNull()) {
@@ -67,6 +83,12 @@ class PLANCKIDEFSource::Config {
           if (e.tagName() == "checkfilename") {
             _checkFilename = true;
           }
+          if (e.tagName() == "checkbaddata") {
+            _checkBadData = true;
+          }
+          if (e.tagName() == "fillmissingdata") {
+            _fillMissingData = true;
+          }
         }
         n = n.nextSibling();
       }
@@ -78,6 +100,7 @@ PLANCKIDEFSource::PLANCKIDEFSource( KConfig *cfg, const QString& filename, const
 : KstDataSource( cfg, filename, type ), _config(0L)
 {
   _fields.setAutoDelete( TRUE );
+  _isHFI = false;
 
   if( type.isEmpty( ) || type == "PLANCKIDEF" )
   {
@@ -476,6 +499,21 @@ void PLANCKIDEFSource::addToFieldList( fitsfile *ffits, const int iNumCols, int
 
           iResult = fits_get_bcolparms( ffits, col+1, ttype, units, dtype, &lRepeat, &dScale, &dZero, &lNull, disp, &iStatus );
 
+          //
+          // if we have a FLAG or SIGNAL field then always append 
+          //  the headerName, as we know that we aren't going to 
+          //  be unique...
+          //
+
+          if ( QString( charName ).upper().compare("FLAG") == 0 ) 
+          {
+            str = QString( "%1_%2" ).arg( charName ).arg( headerName );
+          }
+          else if ( QString( charName ).upper().compare("SIGNAL") == 0 )
+          {
+            str = QString( "%1_%2" ).arg( charName ).arg( headerName );
+          }
+
           if( _fields.find( str ) != 0 )
           {
             str = QString( "%1_%2" ).arg( charName ).arg( headerName );
@@ -494,6 +532,19 @@ void PLANCKIDEFSource::addToFieldList( fitsfile *ffits, const int iNumCols, int
           }
           fld->table = table;
           fld->column = iColNumber;
+          fld->flagColumn = 0;
+
+          //
+          // if we're in a table with 2 columns and
+          //  we're considering the first (signal)
+          //  column, then assume that the second
+          //  column is the flag data...
+          //
+
+          if ( iNumCols == 2 && iColNumber == IDEF_COLUMN_DATA )
+          {
+            fld->flagColumn = IDEF_COLUMN_FLAG;
+          }
 
           _fields.insert( str, fld );
           _fieldList.append( str );
@@ -629,6 +680,21 @@ long PLANCKIDEFSource::getNumFrames( const QString& filename )
 }
 
 
+bool PLANCKIDEFSource::isHFIFile( const QString& filename )
+{
+  QFileInfo pathInfo( filename );
+  QString file( pathInfo.fileName( ) );
+  bool retVal = false;
+
+  if( file.left(1).upper().compare( QString("H") ) == 0 )
+  {
+    retVal = true;
+  }
+
+  return retVal;
+}
+
+
 bool PLANCKIDEFSource::initFile( const QString& filename )
 {
   QString   prefixNew;
@@ -699,6 +765,8 @@ bool PLANCKIDEFSource::initFile( const QString& filename )
           }
         }
 
+        _isHFI = isHFIFile( filename );
+
         bRetVal = true;
       }
     }
@@ -798,6 +866,8 @@ bool PLANCKIDEFSource::initFolderFile( const QString& filename, const QString& p
           }
         }
 
+        _isHFI = isHFIFile( filename );
+
         bRetVal = true;
       }
     }
@@ -851,6 +921,7 @@ bool PLANCKIDEFSource::initFolder( )
             fld->units = QString::null;
             fld->table = 0;
             fld->column = 0;
+            fld->flagColumn = 0;
 
             strIndex = baseName + separator() + "INDEX";
             _fields.insert( strIndex, fld );
@@ -920,6 +991,7 @@ bool PLANCKIDEFSource::initFile( )
 
     fld->table = 0;
     fld->column = 0;
+    fld->flagColumn = 0;
 
     _fields.insert( "INDEX", fld );
     _fieldList.prepend( "INDEX" );
@@ -977,6 +1049,76 @@ KstObject::UpdateType PLANCKIDEFSource::update( int u )
 }
 
 
+/* boxmuller.c           Implements the Polar form of the Box-Muller
+                         Transformation
+
+                      (c) Copyright 1994, Everett F. Carter Jr.
+                          Permission is granted by the author to use
+                          this software for any application provided this
+                          copyright notice is preserved.
+*/
+
+double PLANCKIDEFSource::randomNumberGaussian(double mean, double std)
+{
+  double x1, x2, w, y1;
+  static double y2;
+  static int useLast = 0;
+
+  if( useLast )           /* use value from previous call */
+  {
+    y1 = y2;
+    useLast = 0;
+  }
+  else
+  {
+    do {
+      x1 = 2.0 * ((double)rand()/((double)RAND_MAX+1.0)) - 1.0;
+      x2 = 2.0 * ((double)rand()/((double)RAND_MAX+1.0)) - 1.0;
+      w = x1 * x1 + x2 * x2;
+    } while ( w >= 1.0 );
+
+    w = sqrt( (-2.0 * log( w ) ) / w );
+    y1 = x1 * w;
+    y2 = x2 * w;
+    useLast = 1;
+  }
+
+  return( mean + ( y1 * std ) );
+}
+
+
+bool PLANCKIDEFSource::isInvalidFlag( char flag )
+{
+  bool isInvalid = false;
+
+  if( _isHFI )
+  {
+    if( flag & 0xFF )
+    {
+      //
+      // all bits are treated as error flags...
+      //
+
+      isInvalid = true;
+    }
+  }
+  else
+  {
+    if( flag & 0xFE )
+    {
+      //
+      // the LSB is the manoeuvre flag, 
+      //  but all other bits are treated as error flags...
+      //
+
+      isInvalid = true;
+    }
+  }
+
+  return isInvalid;
+}
+
+
 int PLANCKIDEFSource::readFileFrames( const QString& filename, field *fld, double *v, int s, int n )
 {
   double    dNan = strtod( "nan", NULL );
@@ -1004,6 +1146,27 @@ int PLANCKIDEFSource::readFileFrames( const QString& filename, field *fld, doubl
           {
             iRead = 1;
           }
+
+          if (_config->_checkBadData) {
+            //
+            // check for bad data...
+            //
+
+            if( fld->column == IDEF_COLUMN_DATA && fld->flagColumn == IDEF_COLUMN_FLAG )
+            {
+              char c;
+              char cNan = 0;
+
+              iResult = fits_read_col( ffits, TBYTE, fld->flagColumn, s+1, 1, 1, &cNan, &c, &iAnyNull, &iStatus );
+              if( iResult == 0 )
+              {
+                if( isInvalidFlag( c ) )
+                {
+                  *v = dNan;
+                }
+              }
+            }
+          }
         }
         else
         {
@@ -1012,6 +1175,130 @@ int PLANCKIDEFSource::readFileFrames( const QString& filename, field *fld, doubl
           {
             iRead = n;
           }
+
+          if( _config->_checkBadData  ) {
+            //
+            // check for bad data...
+            //
+
+            if( fld->column == IDEF_COLUMN_DATA && fld->flagColumn == IDEF_COLUMN_FLAG )
+            {
+              double sum = 0.0;
+              double sumSquared = 0.0;
+              int num = 0;
+              char* c = 0L;
+              char cNan = 0;
+
+              c = new char[n];
+              if( c != 0L )
+              {
+                iResult = fits_read_col( ffits, TBYTE, fld->flagColumn, s+1, 1, n, &cNan, c, &iAnyNull, &iStatus );
+                if( iResult == 0 )
+                {
+                  for( int i=0; i<n; ++i )
+                  {
+                    if( isInvalidFlag( c[i] ) )
+                    {
+                      v[i] = dNan;
+                    }
+                    else
+                    {
+                      //
+                      // we assume that we're going to be filling the missing data,
+                      //  so don't bother to check as this would slow us down...
+                      //
+
+                      sum += v[i];
+                      sumSquared += v[i]*v[i];
+                      ++num;
+                    }
+                  }
+
+                  if( _config->_fillMissingData )
+                  {
+                    //
+                    // check that we are actually missing some data,
+                    //  and that we have enough data to calculate the
+                    //  standard deviation...
+                    //
+
+                    if( num < n && num > 0 )
+                    {
+                      double sd;
+                      int start = -1;
+                      int end = -1;
+
+                      sd = sqrt( ( 1.0/(double)num )*( sumSquared - ( sum * sum / (double)num ) ) );
+                      for( int i=0; i<n; ++i )
+                      {
+                        if( start == -1 )
+                        {
+                          //
+                          // find the first missing value in a gap...
+                          //
+
+                          if( isInvalidFlag( c[i] ) )
+                          {
+                            start = i;
+                          }
+                        }
+                        else if( !isInvalidFlag( c[i] ) || i == n-1 )
+                        {
+                          //
+                          // find the last missing value in a gap,
+                          //  which could be the end of the data...
+                          //
+
+                          double left;
+                          double right;
+                          double gradient;
+
+                          if( !isInvalidFlag( c[i] ) )
+                          {
+                            end = i-1;
+                          }
+                          else
+                          {
+                            end = i;
+                          }
+
+                          if( start > 0 )
+                          {
+                            left = v[start-1];
+                          }
+                          else
+                          {
+                            left = v[end+1];
+                          }
+
+                          if( end < n - 1 )
+                          {
+                            right = v[end+1];
+                          }
+                          else
+                          {
+                            right = v[start-1];
+                          }
+
+                          gradient = ( right - left ) / (double)( ( end + 1 ) - ( start - 1 ) );
+
+                          for( int j=start; j<=end; ++j )
+                          {
+                            v[j] = left + ( gradient * (double)( j - start + 1 ) );
+                            v[j] += randomNumberGaussian(0.0, sd);
+                          }
+
+                          start = -1;
+                        }
+                      }
+                    }
+                  }
+                }
+
+                delete[] c;
+              }
+            }
+          }
         }
 
         iStatus = 0;
@@ -1448,6 +1735,28 @@ QString PLANCKIDEFSource::configuration(QString setting)
       return QString("false");
     }
   }
+  else if (setting.lower() == "checkbaddata")
+  {
+    if (_config->_checkBadData) 
+    {
+      return QString("true");
+    }
+    else
+    {
+      return QString("false");
+    }
+  }
+  else if (setting.lower() == "fillmissingdata")
+  {
+    if (_config->_fillMissingData)
+    {
+      return QString("true");
+    }
+    else
+    {
+      return QString("false");
+    }
+  }
 
   return QString();
 }
@@ -1462,6 +1771,22 @@ bool PLANCKIDEFSource::setConfiguration(QString setting, const QString &value) {
       _config->_checkFilename = false;
       return true;
     }
+  } else if (setting.lower() == "checkbaddata") {
+    if (value.lower() == "true") {
+      _config->_checkBadData = true;
+      return true;
+    } else if (value.lower() == "false") {
+      _config->_checkBadData = false;
+      return true;
+    }
+  } else if (setting.lower() == "fillmissingdata") {
+    if (value.lower() == "true") {
+      _config->_fillMissingData = true;
+      return true;
+    } else if (value.lower() == "false") {
+      _config->_fillMissingData = false;
+      return true;
+    }
   }
 
   return false;
@@ -1666,11 +1991,15 @@ class ConfigWidgetPlanckIDEF : public KstDataSourceConfigWidget {
     virtual void load() {
       _cfg->setGroup("PlanckIDEF General");
       _ac->_checkFilename->setChecked(_cfg->readBoolEntry("Check Filename", true));
+      _ac->_checkBadDataFlag->setChecked(_cfg->readBoolEntry("Check Bad Data", true));
+      _ac->_fillMissingData->setChecked(_cfg->readBoolEntry("Fill Missing Data", true));
     }
 
     virtual void save() {
       _cfg->setGroup("PlanckIDEF General");
       _cfg->writeEntry("Check Filename", (int)_ac->_checkFilename->isChecked());
+      _cfg->writeEntry("Check Bad Data", (int)_ac->_checkBadDataFlag->isChecked());
+      _cfg->writeEntry("Fill Missing Data", (int)_ac->_fillMissingData->isChecked());
     }
 
     PlanckIDEFConfig *_ac;
