@@ -34,6 +34,7 @@ typedef struct {
   QString units;
   int table;
   int column;
+  int flagColumn;
 } field;
 
 class PLANCKIDEFSource : public KstDataSource {
@@ -84,12 +85,17 @@ class PLANCKIDEFSource : public KstDataSource {
     bool                  initFolder();
     bool                  initialize();
 
+    double                randomNumberGaussian(double mean, double std);
+    bool                  isInvalidFlag( char flag );
+    bool                  isHFIFile( const QString& filename );
+
     friend class ConfigWidgetPlanckIDEF;
     mutable Config       *_config;
     QDict<field>          _fields;
     QDict<fileList>       _basefiles;
     double                _dTimeZero;
     double                _dTimeDelta;
+    bool                  _isHFI;
     bool                  _bHasTime;
     bool                  _first;
     bool                  _isSingleFile;
