@@ -211,14 +211,17 @@ void KstBindAxis::setLabel(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::StringType) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  if (_xAxis) {
-    _d->xLabel()->setText(value.toString(exec).qstring());
-  } else {
-    _d->yLabel()->setText(value.toString(exec).qstring());
+
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->xLabel()->setText(value.toString(exec).qstring());
+    } else {
+      _d->yLabel()->setText(value.toString(exec).qstring());
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -242,14 +245,18 @@ void KstBindAxis::setTransformation(KJS::ExecState *exec, const KJS::Value& valu
   if (value.type() != KJS::StringType) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  if (_xAxis) {
-    _d->setXTransformedExp(value.toString(exec).qstring());
-  } else {
-    _d->setYTransformedExp(value.toString(exec).qstring());
+
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->setXTransformedExp(value.toString(exec).qstring());
+    } else {
+      _d->setYTransformedExp(value.toString(exec).qstring());
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -273,14 +280,18 @@ void KstBindAxis::setLog(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::BooleanType) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  if (_xAxis) {
-    _d->setLog(value.toBoolean(exec), _d->isYLog());
-  } else {
-    _d->setLog(_d->isXLog(), value.toBoolean(exec));
+
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->setLog(value.toBoolean(exec), _d->isYLog());
+    } else {
+      _d->setLog(_d->isXLog(), value.toBoolean(exec));
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -304,14 +315,18 @@ void KstBindAxis::setMajorGridLines(KJS::ExecState *exec, const KJS::Value& valu
   if (value.type() != KJS::BooleanType) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  if (_xAxis) {
-    _d->setXGridLines(value.toBoolean(exec), _d->hasXMinorGrid());
-  } else {
-    _d->setYGridLines(value.toBoolean(exec), _d->hasYMinorGrid());
+
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->setXGridLines(value.toBoolean(exec), _d->hasXMinorGrid());
+    } else {
+      _d->setYGridLines(value.toBoolean(exec), _d->hasYMinorGrid());
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -335,14 +350,18 @@ void KstBindAxis::setMinorGridLines(KJS::ExecState *exec, const KJS::Value& valu
   if (value.type() != KJS::BooleanType) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  if (_xAxis) {
-    _d->setXGridLines(_d->hasXMajorGrid(), value.toBoolean(exec));
-  } else {
-    _d->setYGridLines(_d->hasYMajorGrid(), value.toBoolean(exec));
+
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->setXGridLines(_d->hasXMajorGrid(), value.toBoolean(exec));
+    } else {
+      _d->setYGridLines(_d->hasYMajorGrid(), value.toBoolean(exec));
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -366,14 +385,18 @@ void KstBindAxis::setReversed(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::BooleanType) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  if (_xAxis) {
-    _d->setXReversed(value.toBoolean(exec));
-  } else {
-    _d->setYReversed(value.toBoolean(exec));
+
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->setXReversed(value.toBoolean(exec));
+    } else {
+      _d->setYReversed(value.toBoolean(exec));
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -400,47 +423,49 @@ void KstBindAxis::setOffsetMode(KJS::ExecState *exec, const KJS::Value& value) {
     return createPropertyTypeError(exec);
   }
 
-  KstWriteLocker wl(_d);
+  {
+    KstWriteLocker wl(_d);
 
-  if (value.type() == KJS::BooleanType) {
-    if (_xAxis) {
-      if (value.toBoolean(exec)) {
-        _d->setXOffsetMode(OFFSET_ON);
+    if (value.type() == KJS::BooleanType) {
+      if (_xAxis) {
+        if (value.toBoolean(exec)) {
+          _d->setXOffsetMode(OFFSET_ON);
+        } else {
+          _d->setXOffsetMode(OFFSET_AUTO);
+        }
       } else {
-        _d->setXOffsetMode(OFFSET_AUTO);
+        if (value.toBoolean(exec)) {
+          _d->setYOffsetMode(OFFSET_ON);
+        } else {
+          _d->setYOffsetMode(OFFSET_AUTO);
+        }
       }
     } else {
-      if (value.toBoolean(exec)) {
-        _d->setYOffsetMode(OFFSET_ON);
+      int iOffset;
+      KstOffsetType offset;
+
+      iOffset = value.toInt32(exec);
+      if (iOffset == OFFSET_AUTO) {
+        offset = OFFSET_AUTO;
+      } else if (iOffset == OFFSET_ON) {
+        offset = OFFSET_ON;
+      } else if (iOffset == OFFSET_OFF) {
+        offset = OFFSET_OFF;
       } else {
-        _d->setYOffsetMode(OFFSET_AUTO);
+        return createPropertyRangeError(exec);
+      }
+
+      if (_xAxis) {
+        _d->setXOffsetMode(offset);
+      } else {
+        _d->setYOffsetMode(offset);
       }
     }
-  } else {
-    int iOffset;
-    KstOffsetType offset;
 
-    iOffset = value.toInt32(exec);
-    if (iOffset == OFFSET_AUTO) {
-      offset = OFFSET_AUTO;
-    } else if (iOffset == OFFSET_ON) {
-      offset = OFFSET_ON;
-    } else if (iOffset == OFFSET_OFF) {
-      offset = OFFSET_OFF;
-    } else {
-      return createPropertyRangeError(exec);
-    }
-
-    if (_xAxis) {
-      _d->setXOffsetMode(offset);
-    } else {
-      _d->setYOffsetMode(offset);
-    }
+    _d->setDirty();
   }
 
-  _d->setDirty();
-
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -464,14 +489,18 @@ void KstBindAxis::setSuppressed(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::BooleanType) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  if (_xAxis) {
-    _d->setSuppressBottom(value.toBoolean(exec));
-  } else {
-    _d->setSuppressLeft(value.toBoolean(exec));
+
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->setSuppressBottom(value.toBoolean(exec));
+    } else {
+      _d->setSuppressLeft(value.toBoolean(exec));
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -495,14 +524,18 @@ void KstBindAxis::setOppositeSuppressed(KJS::ExecState *exec, const KJS::Value&
   if (value.type() != KJS::BooleanType) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  if (_xAxis) {
-    _d->setSuppressTop(value.toBoolean(exec));
-  } else {
-    _d->setSuppressRight(value.toBoolean(exec));
+
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->setSuppressTop(value.toBoolean(exec));
+    } else {
+      _d->setSuppressRight(value.toBoolean(exec));
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -526,14 +559,18 @@ void KstBindAxis::setInnerTicks(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::BooleanType) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  if (_xAxis) {
-    _d->setXTicksInPlot(value.toBoolean(exec));
-  } else {
-    _d->setYTicksInPlot(value.toBoolean(exec));
+
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->setXTicksInPlot(value.toBoolean(exec));
+    } else {
+      _d->setYTicksInPlot(value.toBoolean(exec));
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -557,14 +594,18 @@ void KstBindAxis::setOuterTicks(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::BooleanType) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  if (_xAxis) {
-    _d->setXTicksOutPlot(value.toBoolean(exec));
-  } else {
-    _d->setYTicksOutPlot(value.toBoolean(exec));
+
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->setXTicksOutPlot(value.toBoolean(exec));
+    } else {
+      _d->setYTicksOutPlot(value.toBoolean(exec));
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -585,10 +626,14 @@ void KstBindAxis::setMajorGridColor(KJS::ExecState *exec, const KJS::Value& valu
   if (!cv.canCast(QVariant::Color)) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker rl(_d);
-  _d->setGridLinesColor(cv.toColor(), _d->minorGridColor(), false, _d->defaultMinorGridColor());
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  {
+    KstWriteLocker wl(_d);
+    _d->setGridLinesColor(cv.toColor(), _d->minorGridColor(), false, _d->defaultMinorGridColor());
+    _d->setDirty();
+  }
+
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -609,10 +654,14 @@ void KstBindAxis::setMinorGridColor(KJS::ExecState *exec, const KJS::Value& valu
   if (!cv.canCast(QVariant::Color)) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker rl(_d);
-  _d->setGridLinesColor(_d->majorGridColor(), cv.toColor(), _d->defaultMajorGridColor(), false);
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  {
+    KstWriteLocker wl(_d);
+    _d->setGridLinesColor(_d->majorGridColor(), cv.toColor(), _d->defaultMajorGridColor(), false);
+    _d->setDirty();
+  }
+
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -642,14 +691,17 @@ void KstBindAxis::setMinorTickCount(KJS::ExecState *exec, const KJS::Value& valu
     return createPropertyTypeError(exec);
   }
 
-  KstWriteLocker rl(_d);
-  if (_xAxis) {
-    _d->setXMinorTicks(value.toInt32(exec));
-  } else {
-    _d->setYMinorTicks(value.toInt32(exec));
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->setXMinorTicks(value.toInt32(exec));
+    } else {
+      _d->setYMinorTicks(value.toInt32(exec));
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -710,21 +762,25 @@ void KstBindAxis::setMajorTickDensity(KJS::ExecState *exec, const KJS::Value& va
       return createPropertyRangeError(exec);
   }
 
-  KstWriteLocker rl(_d);
-  if (_xAxis) {
-    _d->setXMajorTicks(i);
-  } else {
-    _d->setYMajorTicks(i);
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->setXMajorTicks(i);
+    } else {
+      _d->setYMajorTicks(i);
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
 }
 
 
 KJS::Value KstBindAxis::scaleMode(KJS::ExecState *exec) const {
   if (!_d) {
     return createInternalError(exec);
-}
+  }
+
   KstReadLocker rl(_d);
   KstScaleModeType i;
   if (_xAxis) {
@@ -732,8 +788,7 @@ KJS::Value KstBindAxis::scaleMode(KJS::ExecState *exec) const {
   } else {
     i = _d->yScaleMode();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
   return KJS::Number(i);
 }
 
@@ -747,14 +802,17 @@ KJS::Value KstBindAxis::scaleAuto(KJS::ExecState *exec, const KJS::List& args) {
     return createSyntaxError(exec);
   }
 
-  KstWriteLocker rl(_d);
-  if (_xAxis) {
-    _d->setXScaleMode(AUTO);
-  } else {
-    _d->setYScaleMode(AUTO);
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->setXScaleMode(AUTO);
+    } else {
+      _d->setYScaleMode(AUTO);
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
   return KJS::Undefined();
 }
 
@@ -768,14 +826,17 @@ KJS::Value KstBindAxis::scaleAutoSpikeInsensitive(KJS::ExecState *exec, const KJ
     return createSyntaxError(exec);
   }
 
-  KstWriteLocker rl(_d);
-  if (_xAxis) {
-    _d->setXScaleMode(NOSPIKE);
-  } else {
-    _d->setYScaleMode(NOSPIKE);
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->setXScaleMode(NOSPIKE);
+    } else {
+      _d->setYScaleMode(NOSPIKE);
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
   return KJS::Undefined();
 }
 
@@ -795,16 +856,19 @@ KJS::Value KstBindAxis::scaleExpression(KJS::ExecState *exec, const KJS::List& a
     return createTypeError(exec, 1);
   }
 
-  KstWriteLocker rl(_d);
-  if (_xAxis) {
-    _d->setXScaleMode(EXPRESSION);
-    _d->setXExpressions(args[0].toString(exec).qstring(), args[1].toString(exec).qstring());
-  } else {
-    _d->setYScaleMode(EXPRESSION);
-    _d->setYExpressions(args[0].toString(exec).qstring(), args[1].toString(exec).qstring());
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->setXScaleMode(EXPRESSION);
+      _d->setXExpressions(args[0].toString(exec).qstring(), args[1].toString(exec).qstring());
+    } else {
+      _d->setYScaleMode(EXPRESSION);
+      _d->setYExpressions(args[0].toString(exec).qstring(), args[1].toString(exec).qstring());
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
   return KJS::Undefined();
 }
 
@@ -824,16 +888,19 @@ KJS::Value KstBindAxis::scaleRange(KJS::ExecState *exec, const KJS::List& args)
     return createTypeError(exec, 1);
   }
 
-  KstWriteLocker rl(_d);
-  if (_xAxis) {
-    _d->setXScaleMode(FIXED);
-    _d->setXScale(args[0].toNumber(exec), args[1].toNumber(exec));
-  } else {
-    _d->setYScaleMode(FIXED);
-    _d->setYScale(args[0].toNumber(exec), args[1].toNumber(exec));
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->setXScaleMode(FIXED);
+      _d->setXScale(args[0].toNumber(exec), args[1].toNumber(exec));
+    } else {
+      _d->setYScaleMode(FIXED);
+      _d->setYScale(args[0].toNumber(exec), args[1].toNumber(exec));
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
   return KJS::Undefined();
 }
 
