@@ -170,14 +170,18 @@ void KstBindAxisLabel::setText(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::StringType) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  if (_xAxis) {
-    _d->xLabel()->setText(value.toString(exec).qstring());
-  } else {
-    _d->yLabel()->setText(value.toString(exec).qstring());
+
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->xLabel()->setText(value.toString(exec).qstring());
+    } else {
+      _d->yLabel()->setText(value.toString(exec).qstring());
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -188,14 +192,18 @@ void KstBindAxisLabel::setFont(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::StringType) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  if (_xAxis) {
-    _d->xLabel()->setFontName(value.toString(exec).qstring());
-  } else {
-    _d->yLabel()->setFontName(value.toString(exec).qstring());
+
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->xLabel()->setFontName(value.toString(exec).qstring());
+    } else {
+      _d->yLabel()->setFontName(value.toString(exec).qstring());
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -223,14 +231,18 @@ void KstBindAxisLabel::setFontSize(KJS::ExecState *exec, const KJS::Value& value
   if (value.type() != KJS::NumberType || !value.toUInt32(i)) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  if (_xAxis) {
-    _d->xLabel()->setFontSize(i);
-  } else {
-    _d->yLabel()->setFontSize(i);
+
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->xLabel()->setFontSize(i);
+    } else {
+      _d->yLabel()->setFontSize(i);
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
 }
 
 
