@@ -243,7 +243,7 @@ void KstBindBinnedMap::setX(KJS::ExecState *exec, const KJS::Value& value) {
   if (v) {
     KstDataObjectPtr d = makeDataObject(_d);
     if (d) {
-      KstWriteLocker rl(d);
+      KstWriteLocker wl(d);
       if (v) {
         d->inputVectors()[VECTOR_X] = v;
       } else {
@@ -273,7 +273,7 @@ void KstBindBinnedMap::setY(KJS::ExecState *exec, const KJS::Value& value) {
   if (v) {
     KstDataObjectPtr d = makeDataObject(_d);
     if (d) {
-      KstWriteLocker rl(d);
+      KstWriteLocker wl(d);
       if (v) {
         d->inputVectors()[VECTOR_Y] = v;
       } else {
@@ -303,7 +303,7 @@ void KstBindBinnedMap::setZ(KJS::ExecState *exec, const KJS::Value& value) {
   if (v) {
     KstDataObjectPtr d = makeDataObject(_d);
     if (d) {
-      KstWriteLocker rl(d);
+      KstWriteLocker wl(d);
       if (v) {
         d->inputVectors()[VECTOR_Z] = v;
       } else {
@@ -335,7 +335,7 @@ void KstBindBinnedMap::setBinnedMap(KJS::ExecState *exec, const KJS::Value& valu
 
   KstDataObjectPtr d = makeDataObject(_d);
   if (d) {
-    KstWriteLocker rl(d);
+    KstWriteLocker wl(d);
     QString name = value.toString(exec).qstring();
     QString tname;
 
@@ -372,7 +372,7 @@ void KstBindBinnedMap::setHitsMap(KJS::ExecState *exec, const KJS::Value& value)
 
   KstDataObjectPtr d = makeDataObject(_d);
   if (d) {
-    KstWriteLocker rl(d);
+    KstWriteLocker wl(d);
     QString name = value.toString(exec).qstring();
     QString tname;
 
@@ -406,7 +406,7 @@ void KstBindBinnedMap::setXFrom(KJS::ExecState *exec, const KJS::Value& value) {
   if (s) {
     KstDataObjectPtr d = makeDataObject(_d);
     if (d) {
-      KstWriteLocker rl(d);
+      KstWriteLocker wl(d);
       if (s) {
         d->inputScalars()[XMIN] = s;
       } else {
@@ -436,7 +436,7 @@ void KstBindBinnedMap::setXTo(KJS::ExecState *exec, const KJS::Value& value) {
   if (s) {
     KstDataObjectPtr d = makeDataObject(_d);
     if (d) {
-      KstWriteLocker rl(d);
+      KstWriteLocker wl(d);
       if (s) {
         d->inputScalars()[XMAX] = s;
       } else {
@@ -466,7 +466,7 @@ void KstBindBinnedMap::setYFrom(KJS::ExecState *exec, const KJS::Value& value) {
   if (s) {
     KstDataObjectPtr d = makeDataObject(_d);
     if (d) {
-      KstWriteLocker rl(d);
+      KstWriteLocker wl(d);
       if (s) {
         d->inputScalars()[YMIN] = s;
       } else {
@@ -496,7 +496,7 @@ void KstBindBinnedMap::setYTo(KJS::ExecState *exec, const KJS::Value& value) {
   if (s) {
     KstDataObjectPtr d = makeDataObject(_d);
     if (d) {
-      KstWriteLocker rl(d);
+      KstWriteLocker wl(d);
       if (s) {
         d->inputScalars()[YMAX] = s;
       } else {
@@ -526,7 +526,7 @@ void KstBindBinnedMap::setNX(KJS::ExecState *exec, const KJS::Value& value) {
   if (s) {
     KstDataObjectPtr d = makeDataObject(_d);
     if (d) {
-      KstWriteLocker rl(d);
+      KstWriteLocker wl(d);
       if (s) {
         d->inputScalars()[NX] = s;
       } else {
@@ -556,7 +556,7 @@ void KstBindBinnedMap::setNY(KJS::ExecState *exec, const KJS::Value& value) {
   if (s) {
     KstDataObjectPtr d = makeDataObject(_d);
     if (d) {
-      KstWriteLocker rl(d);
+      KstWriteLocker wl(d);
       if (s) {
         d->inputScalars()[NY] = s;
       } else {
@@ -586,7 +586,7 @@ void KstBindBinnedMap::setAutobin(KJS::ExecState *exec, const KJS::Value& value)
   if (s) {
     KstDataObjectPtr d = makeDataObject(_d);
     if (d) {
-      KstWriteLocker rl(d);
+      KstWriteLocker wl(d);
       if (s) {
         d->inputScalars()[AUTOBIN] = s;
       } else {
