@@ -75,7 +75,7 @@ KJS::Object KstBindBox::construct(KJS::ExecState *exec, const KJS::List& args) {
 
   KstViewBoxPtr b = new KstViewBox;
   view->appendChild(b.data());
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+  KstApp::inst()->paintAllFromScript();
   return KJS::Object(new KstBindBox(exec, b));
 }
 
@@ -219,9 +219,11 @@ void KstBindBox::setXRound(KJS::ExecState *exec, const KJS::Value& value) {
   }
   KstViewBoxPtr d = makeBox(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setXRound(w);
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setXRound(w);
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -245,9 +247,11 @@ void KstBindBox::setYRound(KJS::ExecState *exec, const KJS::Value& value) {
   }
   KstViewBoxPtr d = makeBox(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setYRound(w);
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setYRound(w);
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -271,9 +275,11 @@ void KstBindBox::setBorderWidth(KJS::ExecState *exec, const KJS::Value& value) {
   }
   KstViewBoxPtr d = makeBox(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setBorderWidth(borderWidth);
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setBorderWidth(borderWidth);
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -297,9 +303,11 @@ void KstBindBox::setBorderColor(KJS::ExecState *exec, const KJS::Value& value) {
   }
   KstViewBoxPtr d = makeBox(_d);
   if (d) {
-    KstWriteLocker rl(d);
-    d->setBorderColor(cv.toColor());
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setBorderColor(cv.toColor());
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
