@@ -149,20 +149,36 @@ KJS::Value KstBindCurveCollection::append(KJS::ExecState *exec, const KJS::List&
     if (!p) {
       return createTypeError(exec, 0);
     }
-    KstWriteLocker rl(p);
-    if (!p->Curves.contains(c.data())) {
-      p->addCurve(c.data());
-      KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+    bool repaint = false;
+
+    {
+      KstWriteLocker wl(p);
+
+
+      if (!p->Curves.contains(c.data())) {
+        p->addCurve(c.data());
+        repaint = true;
+      }
     }
+
+    if (repaint) {
+      KstApp::inst()->paintAllFromScript();
+    }
+
     return KJS::Undefined();
   } else if (_legend) {
     KstVCurvePtr c = extractVCurve(exec, args[0]);
     if (!c) {
       return createTypeError(exec, 0);
     }
-    KstWriteLocker rl(_legend);
-    _legend->addCurve(c.data());
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+    {
+      KstWriteLocker wl(_legend);
+      _legend->addCurve(c.data());
+    }
+
+    KstApp::inst()->paintAllFromScript();
     return KJS::Undefined();
   }
 
@@ -193,10 +209,19 @@ KJS::Value KstBindCurveCollection::remove(KJS::ExecState *exec, const KJS::List&
 
     KstVCurvePtr c = extractVCurve(exec, args[0], false);
     if (c) {
-      KstWriteLocker rl(p);
-      if (p->Curves.contains(c.data())) {
-        p->removeCurve(c.data());
-        KstApp::inst()->paintAll(KstPainter::P_PAINT);
+      bool repaint = false;
+
+      {
+        KstWriteLocker wl(p);
+
+        if (p->Curves.contains(c.data())) {
+          p->removeCurve(c.data());
+          repaint = true;
+        }
+      }
+
+      if (repaint) {
+        KstApp::inst()->paintAllFromScript();
       }
     } else {
       unsigned i = 0;
@@ -204,9 +229,11 @@ KJS::Value KstBindCurveCollection::remove(KJS::ExecState *exec, const KJS::List&
         if (i >= p->Curves.count()) {
           return createRangeError(exec, 0);
         } else {
-          KstWriteLocker rl(p);
-          p->removeCurve(p->Curves[i].data());
-          KstApp::inst()->paintAll(KstPainter::P_PAINT);
+          {
+            KstWriteLocker wl(p);
+            p->removeCurve(p->Curves[i].data());
+          }
+          KstApp::inst()->paintAllFromScript();
         }
       } else {
         return createTypeError(exec, 0);
@@ -217,21 +244,26 @@ KJS::Value KstBindCurveCollection::remove(KJS::ExecState *exec, const KJS::List&
     KstVCurvePtr c = extractVCurve(exec, args[0], false);
     if (!c) {
       unsigned i = 0;
+
       if (args[0].type() == KJS::NumberType && args[0].toUInt32(i)) {
         if (i >= _legend->curves().count()) {
           return createRangeError(exec, 0);
         } else {
-          KstWriteLocker rl(_legend);
-          _legend->removeCurve(_legend->curves()[i]);
-          KstApp::inst()->paintAll(KstPainter::P_PAINT);
+          {
+            KstWriteLocker wl(_legend);
+            _legend->removeCurve(_legend->curves()[i]);
+          }
+          KstApp::inst()->paintAllFromScript();
         }
       } else {
         return createTypeError(exec, 0);
       }
     } else {
-      KstWriteLocker rl(_legend);
-      _legend->removeCurve(c.data());
-      KstApp::inst()->paintAll(KstPainter::P_PAINT);
+      {
+        KstWriteLocker wl(_legend);
+        _legend->removeCurve(c.data());
+      }
+      KstApp::inst()->paintAllFromScript();
     }
     return KJS::Undefined();
   }
@@ -251,15 +283,19 @@ KJS::Value KstBindCurveCollection::clear(KJS::ExecState *exec, const KJS::List&
       return createInternalError(exec);
     }
     if (!p->Curves.isEmpty()) {
-      KstWriteLocker rl(p);
-      p->clearCurves();
-      KstApp::inst()->paintAll(KstPainter::P_PAINT);
+      {
+        KstWriteLocker wl(p);
+        p->clearCurves();
+      }
+      KstApp::inst()->paintAllFromScript();
     }
     return KJS::Undefined();
   } else if (_legend) {
-    KstWriteLocker rl(_legend);
-    _legend->clear();
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(_legend);
+      _legend->clear();
+    }
+    KstApp::inst()->paintAllFromScript();
     return KJS::Undefined();
   }
 
