@@ -565,7 +565,14 @@ KJS::Value KstBindDataVector::startFrame(KJS::ExecState *exec) const {
   Q_UNUSED(exec)
   KstRVectorPtr v = makeDataVector(_d);
   KstReadLocker rl(v);
-  return KJS::Number(v->startFrame());
+  KstFrameSize value;
+
+  value = v->startFrame();
+  if (value > INT_MAX) {
+    return createRangeError(exec, 0);
+  }
+
+  return KJS::Number((int)value);
 }
 
 
@@ -581,7 +588,14 @@ KJS::Value KstBindDataVector::startFrameRequested(KJS::ExecState *exec) const {
   Q_UNUSED(exec)
   KstRVectorPtr v = makeDataVector(_d);
   KstReadLocker rl(v);
-  return KJS::Number(v->reqStartFrame());
+  KstFrameSize value;
+
+  value = v->reqStartFrame();
+  if (value > INT_MAX) {
+    return createRangeError(exec, 0);
+  }
+
+  return KJS::Number((int)value);
 }
 
 
