@@ -115,7 +115,7 @@ KJS::Value KstBindExtension::get(KJS::ExecState *exec, const KJS::Identifier& pr
       return (this->*extensionProperties[i].get)(exec);
     }
   }
-  
+
   return KstBinding::get(exec, propertyName);
 }
 
@@ -123,16 +123,12 @@ KJS::Value KstBindExtension::get(KJS::ExecState *exec, const KJS::Identifier& pr
 KJS::Value KstBindExtension::call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args) {
   int id = this->id();
   if (id <= 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   KstBindExtension *imp = dynamic_cast<KstBindExtension*>(self.imp());
   if (!imp) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   return (imp->*extensionBindings[id - 1].method)(exec, args);
@@ -161,9 +157,7 @@ KJS::Value KstBindExtension::loaded(KJS::ExecState *exec) const {
 
 KJS::Value KstBindExtension::load(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   ExtensionMgr::self()->setEnabled(_d, true);
@@ -174,9 +168,7 @@ KJS::Value KstBindExtension::load(KJS::ExecState *exec, const KJS::List& args) {
 
 KJS::Value KstBindExtension::unload(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   ExtensionMgr::self()->setEnabled(_d, false);
