@@ -94,6 +94,8 @@ static KstBindings kstBindings[] = {
   { "writeHistory", &KstBindKst::writeHistory },
   { "clearHistory", &KstBindKst::clearHistory },
   { "addToOutput", &KstBindKst::addToOutput },
+  { "autoWriteHistory", &KstBindKst::autoWriteHistory },
+  { "forceRepaint", &KstBindKst::forceRepaint },
   { 0L, 0L }
 };
 
@@ -111,6 +113,7 @@ static KstProperties kstProperties[] = {
   { "document", 0L, &KstBindKst::document },
   { "pluginManager", 0L, &KstBindKst::pluginManager },
   { "gui", 0L, &KstBindKst::gui },
+  { "enableRepaints", &KstBindKst::setRepaintEnabled, &KstBindKst::repaintEnabled },
   { 0L, 0L, 0L }
 };
 
@@ -145,6 +148,23 @@ bool KstBindKst::hasProperty(KJS::ExecState *exec, const KJS::Identifier& proper
 }
 
 
+void KstBindKst::put(KJS::ExecState *exec, const KJS::Identifier& propertyName, const KJS::Value& value, int attr) {
+  QString prop = propertyName.qstring();
+
+  for (int i = 0; kstProperties[i].name; ++i) {
+    if (prop == kstProperties[i].name) {
+      if (!kstProperties[i].set) {
+        break;
+      }
+      (this->*kstProperties[i].set)(exec, value);
+      return;
+    }
+  }
+
+  KstBinding::put(exec, propertyName, value, attr);
+}
+
+
 KJS::Value KstBindKst::get(KJS::ExecState *exec, const KJS::Identifier& propertyName) const {
   if (propertyName.qstring() == "version") {
     return KJS::String(KSTVERSION);
@@ -155,6 +175,7 @@ KJS::Value KstBindKst::get(KJS::ExecState *exec, const KJS::Identifier& property
   }
 
   QString prop = propertyName.qstring();
+
   for (int i = 0; kstProperties[i].name; ++i) {
     if (prop == kstProperties[i].name) {
       if (!kstProperties[i].get) {
@@ -296,6 +317,46 @@ KJS::Value KstBindKst::writeHistory(KJS::ExecState *exec, const KJS::List& args)
 }
 
 
+KJS::Value KstBindKst::autoWriteHistory(KJS::ExecState *exec, const KJS::List& args) {
+  if (args.size() == 0 || args.size() > 2) {
+    return createSyntaxError(exec);
+  }
+
+  if (args[0].type() != KJS::StringType) {
+    return createTypeError(exec, 0);
+  }
+
+  bool append = false;
+
+  if (args.size() == 2) {
+    if (args[1].type() != KJS::BooleanType) {
+      return createTypeError(exec, 1);
+    } else {
+      append = args[1].toBoolean(exec);
+    }
+  }
+
+  if (_ext) {
+    if (_ext->autoWriteHistory(args[0].toString(exec).qstring(), append)) {
+      return KJS::Boolean(true);
+    }
+  }
+
+  return KJS::Boolean(false);
+}
+
+
+KJS::Value KstBindKst::forceRepaint(KJS::ExecState *exec, const KJS::List& args) {
+  if (args.size() != 0) {
+    return createSyntaxError(exec);
+  }
+
+  KstApp::inst()->paintAllFromScript();
+
+  return KJS::Boolean(true);
+}
+
+
 KJS::Value KstBindKst::clearHistory(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 0) {
     return createSyntaxError(exec);
@@ -386,5 +447,22 @@ KJS::Value KstBindKst::pluginManager(KJS::ExecState *exec) const {
 
 KJS::Value KstBindKst::gui(KJS::ExecState *exec) const {
   Q_UNUSED(exec)
+
   return _ext->part()->bind(_ext->app());
 }
+
+
+void KstBindKst::setRepaintEnabled(KJS::ExecState *exec, const KJS::Value& value) {
+  if (value.type() != KJS::BooleanType) {
+    return createPropertyTypeError(exec);
+  }
+
+  KstApp::inst()->setEnableImplicitRepaintsFromScript(value.toBoolean(exec));
+}
+
+
+KJS::Value KstBindKst::repaintEnabled(KJS::ExecState *exec) const {
+  Q_UNUSED(exec)
+
+  return KJS::Boolean(KstApp::inst()->getEnableImplicitRepaintsFromScript());
+}
