@@ -35,6 +35,7 @@ class KstBindKst : public KstBinding {
     ~KstBindKst();
 
     KJS::Value call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args);
+    void put(KJS::ExecState *exec, const KJS::Identifier& propertyName, const KJS::Value& value, int attr = KJS::None);
     KJS::Value get(KJS::ExecState *exec, const KJS::Identifier& propertyName) const;
     KJS::ReferenceList propList(KJS::ExecState *exec, bool recursive = true);
     bool hasProperty(KJS::ExecState *exec, const KJS::Identifier& propertyName) const;
@@ -90,6 +91,20 @@ class KstBindKst : public KstBinding {
     */
     KJS::Value addToOutput(KJS::ExecState *exec, const KJS::List& args);
 
+    /* @method autoWriteHistory
+       @arg string filename The name of the file to save commands to automatically. 
+                            Entering a blank filename will stop the saving of commands.
+       @optarg boolean append If true and the file already exists then commands will be appended
+                            to the existing file.
+       @description Saves commands automatically to a file.
+    */
+    KJS::Value autoWriteHistory(KJS::ExecState *exec, const KJS::List& args);
+
+    /* @method forceRepaint
+       @description Forces a repaint regardless of the value of repaintEnabled.
+    */
+    KJS::Value forceRepaint(KJS::ExecState *exec, const KJS::List& args);
+
     /* @property DataSourceCollection dataSources
        @readonly
        @description The list of all loaded data sources.
@@ -166,6 +181,16 @@ class KstBindKst : public KstBinding {
     */
     KJS::Value gui(KJS::ExecState *exec) const;
 
+    /* @property boolean repaintEnabled
+       @description Determines whether or not manipulation of the Kst interface
+                    through scripting will trigger a repaint.
+                    Setting this to false before issuing a long series of commands
+                    (that each triggers a repaint), and then setting it back to
+                    true can greatly enhance the response time of Kst.
+    */
+    void setRepaintEnabled(KJS::ExecState *exec, const KJS::Value& value);
+    KJS::Value repaintEnabled(KJS::ExecState *exec) const;
+
   protected:
     KstBindKst(int id);
     void addBindings(KJS::ExecState *exec, KJS::Object& obj);
