@@ -85,7 +85,7 @@ KJS::Object KstBindLegend::construct(KJS::ExecState *exec, const KJS::List& args
 
   KstViewLegendPtr b = new KstViewLegend;
   view->appendChild(b.data());
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+  KstApp::inst()->paintAllFromScript();
   return KJS::Object(new KstBindLegend(exec, b));
 }
 
@@ -117,6 +117,7 @@ static LegendProperties legendProperties[] = {
   { "vertical", &KstBindLegend::setVertical, &KstBindLegend::vertical },
   { "curves", 0L, &KstBindLegend::curves },
   { "title", &KstBindLegend::setTitle, &KstBindLegend::title },
+  { "scaleLineWidth", &KstBindLegend::setScaleLineWidth, &KstBindLegend::scaleLineWidth },
   { 0L, 0L, 0L }
 };
 
@@ -235,9 +236,11 @@ KJS::Value KstBindLegend::addCurve(KJS::ExecState *exec, const KJS::List& args)
   if (curve) {
     KstViewLegendPtr d = makeLegend(_d);
     if (d) {
-      KstWriteLocker wl(d);
-      d->addCurve(curve);
-      KstApp::inst()->paintAll(KstPainter::P_PAINT);
+      {
+        KstWriteLocker wl(d);
+        d->addCurve(curve);
+      }
+      KstApp::inst()->paintAllFromScript();
     }
   } else {
     return createTypeError(exec, 0);
@@ -257,9 +260,11 @@ KJS::Value KstBindLegend::removeCurve(KJS::ExecState *exec, const KJS::List& arg
   if (curve) {
     KstViewLegendPtr d = makeLegend(_d);
     if (d) {
-      KstWriteLocker wl(d);
-      d->removeCurve(curve);
-      KstApp::inst()->paintAll(KstPainter::P_PAINT);
+      {
+        KstWriteLocker wl(d);
+        d->removeCurve(curve);
+      }
+      KstApp::inst()->paintAllFromScript();
     }
   } else {
     return createTypeError(exec, 0);
@@ -275,9 +280,11 @@ void KstBindLegend::setFont(KJS::ExecState *exec, const KJS::Value& value) {
   }
   KstViewLegendPtr d = makeLegend(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setFontName(value.toString(exec).qstring());
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setFontName(value.toString(exec).qstring());
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -300,9 +307,11 @@ void KstBindLegend::setFontSize(KJS::ExecState *exec, const KJS::Value& value) {
   }
   KstViewLegendPtr d = makeLegend(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setFontSize(i);
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setFontSize(i);
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -325,9 +334,11 @@ void KstBindLegend::setTextColor(KJS::ExecState *exec, const KJS::Value& value)
   }
   KstViewLegendPtr d = makeLegend(_d);
   if (d) {
-    KstWriteLocker rl(d);
-    d->setForegroundColor(cv.toColor());
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setForegroundColor(cv.toColor());
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -348,9 +359,11 @@ void KstBindLegend::setVertical(KJS::ExecState *exec, const KJS::Value& value) {
   }
   KstViewLegendPtr d = makeLegend(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setVertical(value.toBoolean(exec));
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setVertical(value.toBoolean(exec));
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -382,9 +395,11 @@ void KstBindLegend::setTitle(KJS::ExecState *exec, const KJS::Value& value) {
   }
   KstViewLegendPtr d = makeLegend(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setTitle(value.toString(exec).qstring());
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setTitle(value.toString(exec).qstring());
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -399,4 +414,31 @@ KJS::Value KstBindLegend::title(KJS::ExecState *exec) const {
   return KJS::Undefined();
 }
 
+
+void KstBindLegend::setScaleLineWidth(KJS::ExecState *exec, const KJS::Value& value) {
+  unsigned int i = 0;
+  if (value.type() != KJS::NumberType || !value.toUInt32(i)) {
+    return createPropertyTypeError(exec);
+  }
+  KstViewLegendPtr d = makeLegend(_d);
+  if (d) {
+    {
+      KstWriteLocker wl(d);
+      d->setScaleLineWidth(i);
+    }
+    KstApp::inst()->paintAllFromScript();
+  }
+}
+
+
+KJS::Value KstBindLegend::scaleLineWidth(KJS::ExecState *exec) const {
+  Q_UNUSED(exec)
+  KstViewLegendPtr d = makeLegend(_d);
+  if (d) {
+    KstReadLocker rl(d);
+    return KJS::Number(d->scaleLineWidth());
+  }
+  return KJS::Number(0);
+}
+
 #undef makeLegend
