@@ -107,6 +107,13 @@ class KstBindLegend : public KstBindBorderedViewObject {
     void setTitle(KJS::ExecState *exec, const KJS::Value& value);
     KJS::Value title(KJS::ExecState *exec) const;
 
+    /* @property number scaleLineWidth
+       @description Contains the scale factor for the width of the lines in the legend,
+                    relative to the width of the lines in the actual plot.
+    */
+    void setScaleLineWidth(KJS::ExecState *exec, const KJS::Value& value);
+    KJS::Value scaleLineWidth(KJS::ExecState *exec) const;
+
   protected:
     KstBindLegend(int id, const char *name = 0L);
     void addBindings(KJS::ExecState *exec, KJS::Object& obj);
