@@ -48,8 +48,8 @@ class KstBindMatrix : public KstBindObject {
 
     /* @method resize
        @description Resizes the matrix.
-       @arg number columns The new number of columns in the matrix.  Should be &gt;= 1.
-       @arg number rows The new number of rows in the matrix.  Should be &gt;= 1.
+       @arg number columns The new number of rows in the matrix.  Should be &gt;= 1.
+       @arg number rows The new number of columns in the matrix.  Should be &gt;= 1.
        @exception GeneralError Throws this exception if the matrix is not
                                editable.
      */
@@ -63,17 +63,17 @@ class KstBindMatrix : public KstBindObject {
 
     /* @method value
        @returns number
-       @description Gets the value of a matrix at the given row and column indices.
-       @arg number row The row index of the matrix position to be set.
-       @arg number column The column index of the matrix position to be set.
+       @description Gets the value of a matrix at the given column and row indices.
+       @arg number column The column index of the matrix position to be read.
+       @arg number row The row index of the matrix position to be read.
        @exception GeneralError Throws this exception if the indices are out of range.
      */
     KJS::Value value(KJS::ExecState *exec, const KJS::List& args);
 
     /* @method setValue
-       @description Sets the value of a matrix at the given row and column indices.
-       @arg number row The row index of the matrix position to be set.
+       @description Sets the value of a matrix at the given column and row indices.
        @arg number column The column index of the matrix position to be set.
+       @arg number row The row index of the matrix position to be set.
        @arg number value The value to set the specified matrix position to.
        @exception GeneralError Throws this exception if the matrix is not editable or the indices are out of range.
      */
@@ -112,7 +112,7 @@ class KstBindMatrix : public KstBindObject {
 
     /* @property number numNew
        @readonly
-       @description The mean value of all samples in the matrix.
+       @description The number of new samples.
      */
     KJS::Value numNew(KJS::ExecState *exec) const;
 
