@@ -161,10 +161,12 @@ void KstBindPlotLabel::setText(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::StringType) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  _d->topLabel()->setText(value.toString(exec).qstring());
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+  {
+    KstWriteLocker wl(_d);
+    _d->topLabel()->setText(value.toString(exec).qstring());
+    _d->setDirty();
+  }
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -175,10 +177,12 @@ void KstBindPlotLabel::setFont(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::StringType) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  _d->topLabel()->setFontName(value.toString(exec).qstring());
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+  {
+    KstWriteLocker wl(_d);
+    _d->topLabel()->setFontName(value.toString(exec).qstring());
+    _d->setDirty();
+  }
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -200,10 +204,12 @@ void KstBindPlotLabel::setFontSize(KJS::ExecState *exec, const KJS::Value& value
   if (value.type() != KJS::NumberType || !value.toUInt32(i)) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  _d->topLabel()->setFontSize(i);
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+  {
+    KstWriteLocker wl(_d);
+    _d->topLabel()->setFontSize(i);
+    _d->setDirty();
+  }
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -224,10 +230,12 @@ void KstBindPlotLabel::setJustification(KJS::ExecState *exec, const KJS::Value&
   if (value.type() != KJS::NumberType || !value.toUInt32(i)) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  _d->topLabel()->setJustification(i);
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+  {
+    KstWriteLocker wl(_d);
+    _d->topLabel()->setJustification(i);
+    _d->setDirty();
+  }
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -248,10 +256,12 @@ void KstBindPlotLabel::setDataPrecision(KJS::ExecState *exec, const KJS::Value&
   if (value.type() != KJS::NumberType || !value.toUInt32(i)) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  _d->topLabel()->setDataPrecision(i);
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+  {
+    KstWriteLocker wl(_d);
+    _d->topLabel()->setDataPrecision(i);
+    _d->setDirty();
+  }
+  KstApp::inst()->paintAllFromScript();
 }
 
 
