@@ -299,6 +299,12 @@ KJS::Value KstBindPlugin::setInput(KJS::ExecState *exec, const KJS::List& args)
           if (vp) {
             d->inputVectors().insert(d->plugin()->data()._inputs[index]._name, vp);
             d->setDirty(true);
+            d->setRecursed(false);
+            if (d->recursion()) {
+              d->setRecursed(true);
+
+              return createGeneralError(exec, i18n("Command resulted in a recursion."));
+            }
           } else {
             return createTypeError(exec, 1);
           }
@@ -307,6 +313,12 @@ KJS::Value KstBindPlugin::setInput(KJS::ExecState *exec, const KJS::List& args)
           if (sp) {
             d->inputStrings().insert(input, sp);
             d->setDirty(true);
+            d->setRecursed(false);
+            if (d->recursion()) {
+              d->setRecursed(true);
+
+              return createGeneralError(exec, i18n("Command resulted in a recursion."));
+            }
           } else {
             return createTypeError(exec, 1);
           }
@@ -316,6 +328,12 @@ KJS::Value KstBindPlugin::setInput(KJS::ExecState *exec, const KJS::List& args)
           if (sp) {
             d->inputScalars().insert(input, sp);
             d->setDirty(true);
+            d->setRecursed(false);
+            if (d->recursion()) {
+              d->setRecursed(true);
+
+              return createGeneralError(exec, i18n("Command resulted in a recursion."));
+            }
           } else {
             return createTypeError(exec, 1);
           }
@@ -396,6 +414,12 @@ KJS::Value KstBindPlugin::setInput(KJS::ExecState *exec, const KJS::List& args)
         if (vp) {
           bp->setInputVector(input, vp);
           bp->setDirty(true);
+          bp->setRecursed(false);
+          if (bp->recursion()) {
+            bp->setRecursed(true);
+
+            return createGeneralError(exec, i18n("Command resulted in a recursion."));
+          }
         } else {
           return createTypeError(exec, 1);
         }
@@ -404,6 +428,12 @@ KJS::Value KstBindPlugin::setInput(KJS::ExecState *exec, const KJS::List& args)
         if (sp) {
           bp->setInputScalar(input, sp);
           bp->setDirty(true);
+          bp->setRecursed(false);
+          if (bp->recursion()) {
+            bp->setRecursed(true);
+
+            return createGeneralError(exec, i18n("Command resulted in a recursion."));
+          }
         } else {
           return createTypeError(exec, 1);
         }
@@ -412,6 +442,12 @@ KJS::Value KstBindPlugin::setInput(KJS::ExecState *exec, const KJS::List& args)
         if (sp) {
           bp->setInputString(input, sp);
           bp->setDirty(true);
+          bp->setRecursed(false);
+          if (bp->recursion()) {
+            bp->setRecursed(true);
+
+            return createGeneralError(exec, i18n("Command resulted in a recursion."));
+          }
         } else {
           return createTypeError(exec, 1);
         }
