@@ -180,6 +180,7 @@ static PowerSpectrumBindings powerSpectrumBindings[] = {
 
 
 static PowerSpectrumProperties powerSpectrumProperties[] = {
+  { "vector", &KstBindPowerSpectrum::setVector, &KstBindPowerSpectrum::vector },
   { "xVector", 0, &KstBindPowerSpectrum::xVector },
   { "yVector", 0, &KstBindPowerSpectrum::yVector },
   { "apodize", &KstBindPowerSpectrum::setApodize, &KstBindPowerSpectrum::apodize },
@@ -336,6 +337,40 @@ KJS::Value KstBindPowerSpectrum::rUnits(KJS::ExecState *exec) const {
 }
 
 
+void KstBindPowerSpectrum::setVector(KJS::ExecState *exec, const KJS::Value& value) {
+  KstPSDPtr d = makePSD(_d);
+  if (!d) {
+    createInternalError(exec);
+  }
+
+  KstVectorPtr v = extractVector(exec, value);
+  if (v) {
+    KstWriteLocker wl(d);
+    d->setVector(v);
+    d->setDirty();
+    d->setRecursed(false);
+    if (d->recursion()) {
+      d->setRecursed(true);
+
+      createGeneralError(exec, i18n("Command resulted in a recursion."));
+    }
+  }
+}
+
+
+KJS::Value KstBindPowerSpectrum::vector(KJS::ExecState *exec) const {
+  KstPSDPtr d = makePSD(_d);
+  if (d) {
+    KstReadLocker rl(d);
+    KstVectorPtr vp = d->vector();
+    if (vp) {
+      return KJS::Object(new KstBindVector(exec, vp));
+    }
+  }
+  return KJS::Null();
+}
+
+
 KJS::Value KstBindPowerSpectrum::xVector(KJS::ExecState *exec) const {
   KstPSDPtr d = makePSD(_d);
   if (d) {
