@@ -48,8 +48,21 @@ KstBindString::~KstBindString() {
 
 
 KJS::Object KstBindString::construct(KJS::ExecState *exec, const KJS::List& args) {
-  Q_UNUSED(args)
-  return KJS::Object(new KstBindString(exec));
+  if (args.size() == 0) {
+    return KJS::Object(new KstBindString(exec));
+  }
+
+  if (args.size() > 1) {
+    return createSyntaxError(exec);
+  }
+
+  if (args[0].type() != KJS::StringType) {
+    return createTypeError(exec, 0);
+  }
+
+  KstStringPtr s = new KstString;
+  s->setValue(args[0].toString(exec).qstring());
+  return KJS::Object(new KstBindString(exec, s));
 }
 
 
