@@ -69,7 +69,6 @@ KstBindVector::KstBindVector(int id, const char *name)
 
 
 KstBindVector::~KstBindVector() {
-  kdDebug() << "Destroy a KstBindVector" << endl;
 }
 
 
@@ -318,6 +317,7 @@ KJS::Value KstBindVector::min(KJS::ExecState *exec) const {
     return createInternalError(exec);
   }
   if (v->dirty()) {
+    KstWriteLocker wl(v);
     v->update();
   }
   KstReadLocker rl(v);
@@ -331,6 +331,7 @@ KJS::Value KstBindVector::max(KJS::ExecState *exec) const {
     return createInternalError(exec);
   }
   if (v->dirty()) {
+    KstWriteLocker wl(v);
     v->update();
   }
   KstReadLocker rl(v);
@@ -344,6 +345,7 @@ KJS::Value KstBindVector::mean(KJS::ExecState *exec) const {
     return createInternalError(exec);
   }
   if (v->dirty()) {
+    KstWriteLocker wl(v);
     v->update();
   }
   KstReadLocker rl(v);
@@ -452,7 +454,6 @@ KJS::Value KstBindVector::valueAt(KJS::ExecState *exec, const KJS::List& args) {
 
 
 KJS::Value KstBindVector::editable(KJS::ExecState *exec) const {
-  Q_UNUSED(exec)
   KstVectorPtr v = makeVector(_d);
   if (!v) {
     return createInternalError(exec);
@@ -463,11 +464,14 @@ KJS::Value KstBindVector::editable(KJS::ExecState *exec) const {
 
 
 KJS::Value KstBindVector::numNaN(KJS::ExecState *exec) const {
-  Q_UNUSED(exec)
   KstVectorPtr v = makeVector(_d);
   if (!v) {
     return createInternalError(exec);
   }
+  if (v->dirty()) {
+    KstWriteLocker wl(v);
+    v->update();
+  }
   KstReadLocker rl(v);
   return KJS::Number(v->numNaN());
 }
