@@ -63,8 +63,16 @@ QStringList KstBindVectorCollection::collection(KJS::ExecState *exec) const {
 
 
 KJS::Value KstBindVectorCollection::extract(KJS::ExecState *exec, const KJS::Identifier& item) const {
-  KstReadLocker rl(&KST::vectorList.lock());
-  KstVectorPtr vp = *KST::vectorList.findTag(item.qstring());
+  KstVectorPtr vp;
+
+  //
+  // the following scope delimiters are used to ensure that the 
+  //  readlock goes out of scope as soon as possible...
+  //
+  {
+    KstReadLocker rl(&KST::vectorList.lock());
+    vp = *KST::vectorList.findTag(item.qstring());
+  }
   if (!vp) {
     return KJS::Undefined();
   }
