@@ -36,6 +36,11 @@ JSIfaceImpl::~JSIfaceImpl() {
 #ifdef KST_HAVE_READLINE
   clear_history();
 #endif
+
+  if (_autoWriteHistoryFile.isOpen()) {
+    _autoWriteHistoryFile.flush();
+    _autoWriteHistoryFile.close();
+  }
 }
 
 
@@ -47,6 +52,12 @@ QString JSIfaceImpl::evaluate(const QString& script) {
   add_history(script.latin1());
 #endif
 
+  if (_autoWriteHistoryFile.isOpen()) {
+    _autoWriteHistoryFile.writeBlock(script.latin1(), script.length());
+    _autoWriteHistoryFile.writeBlock("\n", 1);
+    _autoWriteHistoryFile.flush();
+  }
+
   if (_jsPart->execute(res, script, KJS::Null())) {
     if (!res.isValueCompletion()) {
       return QString::null;
@@ -118,3 +129,26 @@ bool JSIfaceImpl::addToOutput(const QString& output) {
 
   return true;
 }
+
+
+bool JSIfaceImpl::autoWriteHistory(const QString& output, bool append) {
+  bool retVal = false;
+
+  if (_autoWriteHistoryFile.isOpen()) {
+    _autoWriteHistoryFile.flush();
+    _autoWriteHistoryFile.close();
+  }
+
+  if (!output.isEmpty()) {
+    _autoWriteHistoryFile.setName(output);
+    if (append) {
+      retVal = _autoWriteHistoryFile.open(IO_WriteOnly | IO_Append);
+    } else {
+      retVal = _autoWriteHistoryFile.open(IO_WriteOnly | IO_Truncate);
+    }
+  } else {
+    retVal = true;
+  }
+
+  return retVal;
+}
