@@ -52,32 +52,32 @@ static const char description[] = I18N_NOOP("Kst: a data viewing program.");
 static QStringList startupErrors;
 
 static KCmdLineOptions options[] = {
-  { "y <Y>",  I18N_NOOP("Field for Y axis (multiple allowed)"), 0 },
-  { "z <Z>",  I18N_NOOP("Field for a Z image (multiple allowed)"), 0 },
-  { "ye <equation>",  I18N_NOOP("Equation for Y axis (multiple allowed)"), 0 },
-  { "E <text>",  I18N_NOOP("Pass argument to extension.  text is of format extensionname:argumentlist"), 0 },
-  { "e <E>",  I18N_NOOP("Field for Y errors (multiple allowed)"), 0 },
-  { "x <X>",  I18N_NOOP("Field or range for X axis"),        "INDEX"},
-  { "xe <X>", I18N_NOOP("X vector for equations x0:x1:n"),   "INDEX"},
-  { "p <Y>",  I18N_NOOP("Field for power spectrum (multiple allowed)"), 0},
-  { "h <Y>",  I18N_NOOP("Field for histogram (multiple allowed)"), 0},
-  { "r <f>",  I18N_NOOP("Sample rate for power spectrum"),      "60.0"},
-  { "ru <U>", I18N_NOOP("Units for psd sample rate"),           "Hz"},
-  { "yu <U>", I18N_NOOP("Units for y vectors"),                 "V"},
-  { "l <P>",  I18N_NOOP("Length of FFTs is 2^P"),               "10"},
-  { "f <F0>", I18N_NOOP("First frame to read"),                 "-2"},
-  { "n <NS>", I18N_NOOP("Number of frames to read"),            "-2"},
-  { "s <NS>", I18N_NOOP("Number of frames to skip each read"),  "-1"},
-  { "a",      I18N_NOOP("Apply boxcar filter before skipping frames"),0},
-  { "m <NC>", I18N_NOOP("Separate plots arranged in <NC> columns"),0},
-  { "d",      I18N_NOOP("Display as points rather than curves"),0},
-  { "g",      I18N_NOOP("Provide a legend box"),0},
-  { "w <file>",      I18N_NOOP("Display the data wizard"),"<none>"},
-  { "print <file>",  I18N_NOOP("Print to file and exit"),"<none>"},
-  { "png <file>",  I18N_NOOP("Save as a png file and exit"),"<none>"},
-  { "nq",     I18N_NOOP("Bypass the quickstart dialog"), 0},
-  {"F <dataFile>", I18N_NOOP("Override a *.kst file's data file with <datafile>"), "|"},
-  { "+[Files]", I18N_NOOP("Data files (if -y given) or *.kst file"), 0},
+  { "y <Y>", I18N_NOOP("Field for Y axis (multiple allowed)"), 0 },
+  { "z <Z>", I18N_NOOP("Field for a Z image (multiple allowed)"), 0 },
+  { "ye <equation>", I18N_NOOP("Equation for Y axis (multiple allowed)"), 0 },
+  { "E <text>", I18N_NOOP("Pass argument to extension. Text is of format extensionname:argumentlist"), 0 },
+  { "e <E>", I18N_NOOP("Field for Y errors (multiple allowed)"), 0 },
+  { "x <X>", I18N_NOOP("Field or range for X axis"), "INDEX" },
+  { "xe <X>", I18N_NOOP("X vector for equations x0:x1:n"), "INDEX" },
+  { "p <Y>", I18N_NOOP("Field for power spectrum (multiple allowed)"), 0 },
+  { "h <Y>", I18N_NOOP("Field for histogram (multiple allowed)"), 0 },
+  { "r <f>", I18N_NOOP("Sample rate for power spectrum"), "60.0" },
+  { "ru <U>", I18N_NOOP("Units for psd sample rate"), "Hz" },
+  { "yu <U>", I18N_NOOP("Units for y vectors"), "V" },
+  { "l <P>", I18N_NOOP("Length of FFTs is 2^P"), "10" },
+  { "f <F0>", I18N_NOOP("First frame to read"), "-2" },
+  { "n <NS>", I18N_NOOP("Number of frames to read"), "-2" },
+  { "s <NS>", I18N_NOOP("Number of frames to skip each read"), "-1" },
+  { "a", I18N_NOOP("Apply boxcar filter before skipping frames"), 0 },
+  { "m <NC>", I18N_NOOP("Separate plots arranged in <NC> columns"), 0 },
+  { "d", I18N_NOOP("Display as points rather than curves"), 0 },
+  { "g", I18N_NOOP("Provide a legend box"), 0 },
+  { "w <file>", I18N_NOOP("Display the data wizard"), "<none>" },
+  { "print <file>", I18N_NOOP("Print to file and exit"), "<none>" },
+  { "png <file>", I18N_NOOP("Save as a png file and exit"), "<none>" },
+  { "nq", I18N_NOOP("Bypass the quickstart dialog"), 0 },
+  { "F <dataFile>", I18N_NOOP("Override a *.kst file's data file with <datafile>"), "|" },
+  { "+[Files]", I18N_NOOP("Data files (if -y given) or *.kst file"), 0 },
   KCmdLineLastOption
 };
 
@@ -111,7 +111,7 @@ static void CheckForCMDErrors(KCmdLineArgs *args) {
     kstdError() << i18n("Exiting because '-n 0' requests vectors with no data in them.") << endl;
     exit(0); // ugly but now safe
   }
-  if (args->getOption("n").toInt(&nOK)>0) {
+  if (args->getOption("n").toInt(&nOK) > 0) {
     if (args->getOption("n").toInt(&nOK) < 2*args->getOption("s").toInt(&nOK)) {
       kstdError() << i18n("Requested data skipping would leave vector with fewer than two points.") << endl;
       exit(0); // ugly but now safe
@@ -302,7 +302,7 @@ static void ProcessEq(QString &eq, KstDataSourcePtr file, InType &in, bool *ok)
 
   while ((i0 = eq.find('[', i0))>=0) {
     i1 = eq.find(']', i0);
-    if (i1>0) {
+    if (i1 > 0) {
       field = eq.mid(i0+1, i1-i0-1);
       v = GetOrCreateVector(field, file, in);
       if (v) {
@@ -330,7 +330,7 @@ int main(int argc, char *argv[]) {
 
   KAboutData aboutData("kst", I18N_NOOP("Kst"),
                        KSTVERSION, description, KAboutData::License_GPL,
-                       I18N_NOOP("(c) 2000-2007 Barth Netterfield"),
+                       I18N_NOOP("(c) 2000-2009 Barth Netterfield"),
                        0,
                        "http://kst.kde.org/");
   aboutData.addAuthor("Barth Netterfield",
@@ -369,6 +369,10 @@ int main(int argc, char *argv[]) {
                       "",
                       "",
                       "");
+  aboutData.addAuthor("Zongyi Zhang",
+                      "",
+                      "",
+                      "");
   aboutData.setTranslator(I18N_NOOP("_: NAME OF TRANSLATORS\nYour names"), 
                           I18N_NOOP("_: EMAIL OF TRANSLATORS\nYour emails"));
 
