@@ -20,25 +20,17 @@
 #include "kstvector.h"
 #include "kst_export.h"
 
-/**A vector  with n editable pts
- *@author cbn
- */
 class KstAVector : public KstVector {
  public:
   KST_EXPORT KstAVector(const QDomElement &e);
   KST_EXPORT KstAVector(int n, KstObjectTag tag);
 
   void save(QTextStream &ts, const QString& indent = QString::null, bool saveAbsolutePosition = false);
-
   KstObject::UpdateType update(int update_counter);
-
   void setSaveData(bool save);
 };
 
 typedef KstSharedPtr<KstAVector> KstAVectorPtr;
 typedef KstObjectList<KstAVectorPtr> KstAVectorList;
 
-
-
 #endif
-// vim: ts=2 sw=2 et
