@@ -19,24 +19,18 @@
 
 #include <assert.h>
 
-#include "ksdebug.h"
-#include <kio/netaccess.h>
-#include <klibloader.h>
-#include <klocale.h>
-#include <kservicetype.h>
-
 #include <qdeepcopy.h>
 #include <qfile.h>
 #include <qfileinfo.h>
 #include <qstylesheet.h>
 
+#include "ksdebug.h"
 #include "kstdatacollection.h"
+#include "kstdataplugin.h"
 #include "kstdebug.h"
 #include "kstscalar.h"
 #include "stdinsource.h"
 
-#include "kstdataplugin.h"
-
 static KConfig *kConfigObject = 0L;
 static QMap<QString,QString> urlMap;
 void KstDataSource::setupOnStartup(KConfig *cfg) {
@@ -515,41 +509,86 @@ KstObject::UpdateType KstDataSource::update(int u) {
 
 
 void KstDataSource::updateNumFramesScalar() {
-  _numFramesScalar->setValue(frameCount());
+  _numFramesScalar->setValue((double)frameCountLarge());
 }
 
 
-int KstDataSource::readField(double *v, const QString& field, int s, int n, int skip, int *lastFrameRead) {
+int KstDataSource::readFieldSkip(double *v, const QString& field, int s, int n, int skip, int *lastFrameRead) {
   Q_UNUSED(v)
   Q_UNUSED(field)
   Q_UNUSED(s)
   Q_UNUSED(n)
   Q_UNUSED(skip)
   Q_UNUSED(lastFrameRead)
+
   return -9999; // unsupported
 }
 
 
+KstFrameSize KstDataSource::readFieldLargeSkip(double *v, const QString& field, KstFrameSize s, KstFrameSize n, int skip, KstFrameSize *lastFrameRead) {
+  KstFrameSize rc = -9999;
+
+  if (s <= INT_MAX && s+n <= INT_MAX) {
+    int iLastFrameRead;
+
+    rc = (KstFrameSize)readFieldSkip(v, field, (int)s, (int)n, skip, &iLastFrameRead);
+
+    *lastFrameRead = (KstFrameSize)iLastFrameRead;
+
+    return (KstFrameSize)rc;
+  }
+
+  return rc;
+}
+
+
 int KstDataSource::readField(double *v, const QString& field, int s, int n) {
   Q_UNUSED(v)
   Q_UNUSED(field)
   Q_UNUSED(s)
   Q_UNUSED(n)
+
   return -1;
 }
 
+
+KstFrameSize KstDataSource::readFieldLarge(double *v, const QString& field, KstFrameSize s, KstFrameSize n) {
+  KstFrameSize rc = -1;
+
+  if (s <= INT_MAX && n <= INT_MAX) {
+    rc = (KstFrameSize)readField(v, field, (int)s, (int)n);
+  }
+
+  return rc;
+}
+
+
 bool KstDataSource::isWritable() const {
   return _writable;
 }
 
+
 int KstDataSource::writeField(const double *v, const QString& field, int s, int n) {
   Q_UNUSED(v)
   Q_UNUSED(field)
   Q_UNUSED(s)
   Q_UNUSED(n)
+
   return -1;
 }
 
+
+KstFrameSize KstDataSource::writeFieldLarge(const double *v, const QString& field, KstFrameSize s, KstFrameSize n) {
+  KstFrameSize rc = -1;
+
+  if (s <= INT_MAX && s+n <= INT_MAX) {
+    rc = (KstFrameSize)writeField(v, field, (int)s, (int)n);
+  }
+
+  return rc;
+}
+
+
 int KstDataSource::readMatrix(KstMatrixData* data, const QString& matrix, int xStart, int yStart, int xNumSteps, int yNumSteps, int skip) {
   Q_UNUSED(data)
   Q_UNUSED(matrix)
@@ -558,6 +597,7 @@ int KstDataSource::readMatrix(KstMatrixData* data, const QString& matrix, int xS
   Q_UNUSED(xNumSteps)
   Q_UNUSED(yNumSteps)
   Q_UNUSED(skip)
+
   return -9999;
 }
 
@@ -569,6 +609,7 @@ int KstDataSource::readMatrix(KstMatrixData* data, const QString& matrix, int xS
   Q_UNUSED(yStart)
   Q_UNUSED(xNumSteps)
   Q_UNUSED(yNumSteps)
+
   return -1;
 }
 
@@ -577,7 +618,8 @@ bool KstDataSource::matrixDimensions(const QString& matrix, int* xDim, int* yDim
   Q_UNUSED(matrix)
   Q_UNUSED(xDim)
   Q_UNUSED(yDim)
-  return false;  
+
+  return false;
 }
 
 
@@ -588,35 +630,48 @@ bool KstDataSource::isValid() const {
 
 bool KstDataSource::isValidField(const QString& field) const {
   Q_UNUSED(field)
+
   return false;
 }
 
 
 bool KstDataSource::isValidMatrix(const QString& field) const {
   Q_UNUSED(field)
-  return false;  
+
+  return false;
 }
 
 
 int KstDataSource::samplesPerFrame(const QString &field) {
   Q_UNUSED(field)
+
   return 0;
 }
 
 
 int KstDataSource::frameCount(const QString& field) const {
   Q_UNUSED(field)
+
   return 0;
 }
 
 
+KstFrameSize KstDataSource::frameCountLarge(const QString& field) const {
+  return (KstFrameSize)frameCount(field);
+}
+
+
 QString KstDataSource::fileName() const {
-  // Look to see if it was a URL and save the URL instead
+  //
+  // look to see if it was a URL and save the URL instead
+  //
+
   for (QMap<QString,QString>::ConstIterator i = urlMap.begin(); i != urlMap.end(); ++i) {
     if (i.data() == _filename) {
       return i.key();
     }
   }
+
   return _filename;
 }
 
@@ -638,13 +693,18 @@ QString KstDataSource::fileType() const {
 
 void KstDataSource::save(QTextStream &ts, const QString& indent) {
   QString name = QStyleSheet::escape(_filename);
-  // Look to see if it was a URL and save the URL instead
+
+  //
+  // look to see if it was a URL and save the URL instead
+  //
+
   for (QMap<QString,QString>::ConstIterator i = urlMap.begin(); i != urlMap.end(); ++i) {
     if (i.data() == _filename) {
       name = QStyleSheet::escape(i.key());
       break;
     }
   }
+
   ts << indent << "<tag>" << QStyleSheet::escape(tag().tagString()) << "</tag>" << endl;
   ts << indent << "<filename>" << name << "</filename>" << endl;
   ts << indent << "<type>" << QStyleSheet::escape(fileType()) << "</type>" << endl;
@@ -689,9 +749,9 @@ const QDict<KstString>& KstDataSource::metaData() const {
 const QString& KstDataSource::metaData(const QString& key) const {
   if (_metaData[key]) {
     return _metaData[key]->value();
-  } else {
-    return QString::null;
   }
+
+  return QString::null;
 }
 
 
@@ -721,6 +781,11 @@ int KstDataSource::sampleForTime(const KST::ExtDateTime& time, bool *ok) {
 }
 
 
+KstFrameSize KstDataSource::sampleForTimeLarge(const KST::ExtDateTime& time, bool *ok) {
+  return sampleForTime(time, ok);
+}
+
+
 int KstDataSource::sampleForTime(double ms, bool *ok) {
   Q_UNUSED(ms)
 
@@ -732,6 +797,11 @@ int KstDataSource::sampleForTime(double ms, bool *ok) {
 }
 
 
+KstFrameSize KstDataSource::sampleForTimeLarge(double ms, bool *ok) {
+  return sampleForTime(ms, ok);
+}
+
+
 KST::ExtDateTime KstDataSource::timeForSample(int sample, bool *ok) {
   Q_UNUSED(sample)
 
@@ -743,6 +813,19 @@ KST::ExtDateTime KstDataSource::timeForSample(int sample, bool *ok) {
 }
 
 
+KST::ExtDateTime KstDataSource::timeForSampleLarge(KstFrameSize sample, bool *ok) {
+  if (sample <= INT_MAX) {
+    return timeForSample((int)sample, ok);
+  }
+
+  if (ok) {
+    *ok = false;
+  }
+
+  return KST::ExtDateTime::currentDateTime();
+}
+
+
 double KstDataSource::relativeTimeForSample(int sample, bool *ok) {
   Q_UNUSED(sample)
 
@@ -754,6 +837,19 @@ double KstDataSource::relativeTimeForSample(int sample, bool *ok) {
 }
 
 
+double KstDataSource::relativeTimeForSampleLarge(KstFrameSize sample, bool *ok) {
+  if (sample <= INT_MAX) {
+    relativeTimeForSample((int)sample, ok);
+  }
+
+  if (ok) {
+    *ok = false;
+  }
+
+  return 0.0;
+}
+
+
 bool KstDataSource::supportsHierarchy() const {
   return false;
 }
