@@ -19,8 +19,8 @@
 
 #include <config.h>
 
+#include "kstcodecs.h"
 #include "ksttimezones.h"
-#include <kmdcodec.h>
 #include <kprocess.h>
 #include <kstringhandler.h>
 #include <ktempfile.h>
@@ -554,7 +554,7 @@ const KstTimezone *KstTimezones::local()
     if (f.open(IO_ReadOnly))
     {
         // Compute the MD5 sum of /etc/localtime.
-        KMD5 context("");
+        KstMD5 context("");
         context.reset();
         context.update(f);
         QIODevice::Offset referenceSize = f.size();
