@@ -26,9 +26,9 @@
 
 #include <kglobal.h>
 #include <klocale.h>
-#include <kmdcodec.h>
 
 #include "ksdebug.h"
+#include "kstcodecs.h"
 #include "kstdatacollection.h"
 #include "defaultprimitivenames.h"
 #include "kstmath.h"
@@ -43,7 +43,6 @@ static int anonymousVectorCounter = 1;
 
 #define INITSIZE 1
 
-/** Create a vector */
 KstVector::KstVector(KstObjectTag in_tag, int size, KstObject *provider, bool isScalarList)
 : KstPrimitive(provider), _nsum(0), _scalars(isScalarList ? 0 : 11) {
   _editable = false;
@@ -110,7 +109,7 @@ KstVector::KstVector(const QDomElement& e)
       } else if (e.tagName() == "data") {
         QCString qcs(e.text().latin1());
         QByteArray qbca;
-        KCodecs::base64Decode(qcs, qbca);
+        KstCodecs::base64Decode(qcs, qbca);
         qba = qUncompress(qbca);
         sz = kMax((size_t)(INITSIZE), qba.size()/sizeof(double));
       }
@@ -433,6 +432,8 @@ void KstVector::blank() {
 
 
 bool KstVector::resize(int sz, bool reinit) {
+  writeLock();
+
   if (sz > 0) {
     _v = static_cast<double*>(KST::realloc(_v, sz*sizeof(double)));
     if (!_v) {
@@ -452,6 +453,8 @@ bool KstVector::resize(int sz, bool reinit) {
   }
 
   setDirty();
+  unlock();
+
   return true;
 }
 
@@ -611,7 +614,7 @@ void KstVector::save(QTextStream &ts, const QString& indent, bool saveAbsolutePo
       qds << _v[i];
     }
 
-    ts << indent << "<data>" << KCodecs::base64Encode(qCompress(qba)) << "</data>" << endl;
+    ts << indent << "<data>" << KstCodecs::base64Encode(qCompress(qba)) << "</data>" << endl;
   }
 }
 
