@@ -140,7 +140,7 @@ class KST_EXPORT KstVector : public KstPrimitive {
     virtual void setTagName(const KstObjectTag& newTag);
 
     /** Return a pointer to the raw vector */
-    double *const value() const;
+    double* value() const;
 
     /** access functions for _isScalarList */
     bool isScalarList() const { return _isScalarList; }
