@@ -38,6 +38,10 @@ class KST_EXPORT KstBasicDialogI : public KstDataDialog {
     virtual ~KstBasicDialogI();
     static KstBasicDialogI *globalInstance();
 
+  protected:
+    QString editTitle();
+    QString newTitle();
+
   public slots:
     void updateForm();
     virtual void update();
@@ -54,16 +58,17 @@ class KST_EXPORT KstBasicDialogI : public KstDataDialog {
     void init();
 
   private:
-    bool editSingleObject(KstBasicPluginPtr ptr);
+    bool editSingleObject(KstBasicPluginPtr ptr, QString &error);
 
     void createInputVector(const QString &name, int row);
-    void createInputScalar(const QString &name, int row);
+    void createInputScalar(const QString &name, int row, double value);
     void createInputString(const QString &name, int row);
     void createOutputWidget(const QString &name, int row);
 
     VectorSelector *vector(const QString &name) const;
     ScalarSelector *scalar(const QString &name) const;
     StringSelector *string(const QString &name) const;
+    QLabel *label(const QString &name) const;
     QLineEdit *output(const QString &name) const;
 
     static const QString& defaultTag;
@@ -78,4 +83,3 @@ class KST_EXPORT KstBasicDialogI : public KstDataDialog {
 };
 
 #endif
-// vim: ts=2 sw=2 et
