@@ -364,7 +364,15 @@ void KstObjectItem::update(bool recursive, int localUseCount) {
             for (QListViewItem *i = firstChild(); i; i = i->nextSibling()) {
               KstObjectItem *oi = static_cast<KstObjectItem*>(i);
               if (oi->tag().tag() == tn) {
-                oi->update();
+                //
+                // we need to punt here, else we face a potential deadlock,
+                //  as we already have a lock on the dataobject and calling
+                //  update() directly will also put a lock the output vector.
+                //  However, these locks are placed in opposite order in the update
+                //  thread, giving rise to a potential deadlock...
+                //
+
+                QTimer::singleShot(0, oi, SLOT(update()));
                 found = true;
                 break;
               }
@@ -384,7 +392,15 @@ void KstObjectItem::update(bool recursive, int localUseCount) {
             for (QListViewItem *i = firstChild(); i; i = i->nextSibling()) {
               KstObjectItem *oi = static_cast<KstObjectItem*>(i);
               if (oi->tag().tag() == tn) {
-                oi->update();
+                //
+                // we need to punt here, else we face a potential deadlock,
+                //  as we already have a lock on the dataobject and calling
+                //  update() directly will also put a lock the output vector.
+                //  However, these locks are placed in opposite order in the update
+                //  thread, giving rise to a potential deadlock...
+                //
+
+                QTimer::singleShot(0, oi, SLOT(update()));
                 found = true;
                 break;
               }
