@@ -426,39 +426,42 @@ bool KstVectorDialogI::newObject() {
       return false;
     }
 
-    int f0, n;
+    KstFrameSize f0;
+    KstFrameSize n;
+
     if (_w->_kstDataRange->isStartRelativeTime()) {
-      f0 = file->sampleForTime(_w->_kstDataRange->f0Value());
+      f0 = file->sampleForTimeLarge(_w->_kstDataRange->f0Value());
     } else if (_w->_kstDataRange->isStartAbsoluteTime()) {
       bool ok = false;
-      f0 = file->sampleForTime(_w->_kstDataRange->f0DateTimeValue(), &ok);
+      f0 = file->sampleForTimeLarge(_w->_kstDataRange->f0DateTimeValue(), &ok);
       if (!ok) {
         file->unlock();
         KMessageBox::sorry(this, i18n("The requested field or file could not use the specified date."));
         return false;
       }
     } else {
-      f0 = int(_w->_kstDataRange->f0Value());
+      f0 = (KstFrameSize)_w->_kstDataRange->f0Value();
     }
 
     if (_w->_kstDataRange->isRangeRelativeTime()) {
       double nValStored = _w->_kstDataRange->nValue();
       if (_w->_kstDataRange->CountFromEnd->isChecked()) {
-        int frameCount = file->frameCount(_w->Field->currentText());
-        double msCount = file->relativeTimeForSample(frameCount - 1);
-        n = frameCount - 1 - file->sampleForTime(msCount - nValStored);
+        KstFrameSize frameCount = file->frameCountLarge(_w->Field->currentText());
+        double msCount = file->relativeTimeForSampleLarge(frameCount - 1);
+        n = frameCount - 1 - file->sampleForTimeLarge(msCount - nValStored);
       } else {
-        double fTime = file->relativeTimeForSample(f0);
-        n = file->sampleForTime(fTime + nValStored) - file->sampleForTime(fTime);
+        double fTime = file->relativeTimeForSampleLarge(f0);
+        n = file->sampleForTimeLarge(fTime + nValStored) - file->sampleForTimeLarge(fTime);
       }
     } else {
-      n = int(_w->_kstDataRange->nValue());
+      n = (KstFrameSize)_w->_kstDataRange->nValue();
     }
     file->unlock();
 
     //
     // create the vector
     //
+
     KstRVectorPtr vector = new KstRVector(
         file, _w->Field->currentText(),
         KstObjectTag(tagName, file->tag(), false),
@@ -581,11 +584,12 @@ bool KstVectorDialogI::editSingleObjectRV(KstVectorPtr vcPtr) {
       pField = rvp->field();
     }
 
-    int f0 = 0, n = 0;
+    KstFrameSize f0 = 0;
+    KstFrameSize n = 0;
 
     if (_f0Dirty) {
       if (_w->_kstDataRange->isStartRelativeTime()) {
-        f0 = file->sampleForTime(_w->_kstDataRange->f0Value());
+        f0 = file->sampleForTimeLarge(_w->_kstDataRange->f0Value());
       } else if (_w->_kstDataRange->isStartAbsoluteTime()) {
         bool ok = false;
         f0 = file->sampleForTime(_w->_kstDataRange->f0DateTimeValue(), &ok);
@@ -595,22 +599,23 @@ bool KstVectorDialogI::editSingleObjectRV(KstVectorPtr vcPtr) {
           return false;
         }
       } else {
-        f0 = int(_w->_kstDataRange->f0Value());
+        f0 = (KstFrameSize)_w->_kstDataRange->f0Value();
       }
     }
+
     if (_nDirty) {
       if (_w->_kstDataRange->isRangeRelativeTime()) {
         double nValStored = _w->_kstDataRange->nValue();
         if (_w->_kstDataRange->CountFromEnd->isChecked()) {
-          int frameCount = file->frameCount(_w->Field->currentText());
-          double msCount = file->relativeTimeForSample(frameCount - 1);
-          n = frameCount - 1 - file->sampleForTime(msCount - nValStored);
+          KstFrameSize frameCount = file->frameCountLarge(_w->Field->currentText());
+          double msCount = file->relativeTimeForSampleLarge(frameCount - 1);
+          n = frameCount - 1 - file->sampleForTimeLarge(msCount - nValStored);
         } else {
-          double fTime = file->relativeTimeForSample(f0);
-          n = file->sampleForTime(fTime + nValStored) - file->sampleForTime(fTime);
+          double fTime = file->relativeTimeForSampleLarge(f0);
+          n = file->sampleForTimeLarge(fTime + nValStored) - file->sampleForTimeLarge(fTime);
         }
       } else {
-        n = int(_w->_kstDataRange->nValue());
+        n = (KstFrameSize)_w->_kstDataRange->nValue();
       }
     }
 
@@ -623,8 +628,14 @@ bool KstVectorDialogI::editSingleObjectRV(KstVectorPtr vcPtr) {
       n = rvp->reqNumFrames();
     }
 
+    //
     // other parameters for multiple edit
-    bool pCountFromEnd, pReadToEnd, pDoSkip, pDoFilter;
+    //
+
+    bool pCountFromEnd;
+    bool pReadToEnd;
+    bool pDoSkip;
+    bool pDoFilter;
     int pSkip;
 
     if (_countFromEndDirty) {
