@@ -26,9 +26,9 @@
 #include "kstcplugin.h"
 #include "kstsettings.h"
 #include "ksttimers.h"
+#include "kstviewlabelwidget_i.h"
 #include "kstviewobjectfactory.h"
 #include "labelrenderer.h"
-#include "viewlabelwidget.h"
 
 #include <kcolorbutton.h>
 #include <kcombobox.h>
@@ -72,6 +72,7 @@ KstViewLabel::KstViewLabel(const QString& txt, KstLJustifyType justify, float ro
   _labelMargin = 0;
   _isResizable = false;
   _editTitle = i18n("Edit Label");
+  _newTitle = i18n("New Label");
   reparse();
   computeTextSize(_parsed);
 }
@@ -84,6 +85,7 @@ KstViewLabel::KstViewLabel(const QDomElement& e)
   _container = false;
   _type = "Label";
   _editTitle = i18n("Edit Label");
+  _newTitle = i18n("New Label");
   _dataPrecision = 8;
   _interpret = true;
   _replace = true;
@@ -115,6 +117,7 @@ KstViewLabel::KstViewLabel(const QDomElement& e)
 KstViewLabel::KstViewLabel(const KstViewLabel& label)
 : KstBorderedViewObject(label) {
   _editTitle = i18n("Edit Label");
+  _newTitle = i18n("New Label");
 
   _dataPrecision = label._dataPrecision;
   _interpret = label._interpret;
@@ -621,7 +624,7 @@ double KstViewLabel::rotation() const {
 
 
 bool KstViewLabel::fillConfigWidget(QWidget *w, bool isNew) const {
-  ViewLabelWidget *widget = dynamic_cast<ViewLabelWidget*>(w);
+  KstViewLabelWidgetI *widget = dynamic_cast<KstViewLabelWidgetI*>(w);
   if (!widget) {
     return false;
   }
@@ -650,7 +653,7 @@ bool KstViewLabel::fillConfigWidget(QWidget *w, bool isNew) const {
 
 
 bool KstViewLabel::readConfigWidget(QWidget *w, bool editMultipleMode) {
-  ViewLabelWidget *widget = dynamic_cast<ViewLabelWidget*>(w);
+  KstViewLabelWidgetI *widget = dynamic_cast<KstViewLabelWidgetI*>(w);
   if (!widget) {
     return false;
   }
@@ -709,7 +712,7 @@ bool KstViewLabel::readConfigWidget(QWidget *w, bool editMultipleMode) {
 
 
 void KstViewLabel::connectConfigWidget(QWidget *parent, QWidget *w) const {
-  ViewLabelWidget *widget = dynamic_cast<ViewLabelWidget*>(w);
+  KstViewLabelWidgetI *widget = dynamic_cast<KstViewLabelWidgetI*>(w);
   if (!widget) {
     return;
   }
@@ -738,7 +741,7 @@ void KstViewLabel::connectConfigWidget(QWidget *parent, QWidget *w) const {
 
 
 void KstViewLabel::populateEditMultiple(QWidget *w) {
-  ViewLabelWidget *widget = dynamic_cast<ViewLabelWidget*>(w);
+  KstViewLabelWidgetI *widget = dynamic_cast<KstViewLabelWidgetI*>(w);
   if (!widget) {
     return;
   }
@@ -871,7 +874,7 @@ int KstViewLabel::labelMargin() const {
 
 
 QWidget *KstViewLabel::configWidget(QWidget *parent) {
-  return new ViewLabelWidget(parent, "custom");
+  return new KstViewLabelWidgetI(parent, "custom");
 }
 
 
