@@ -38,6 +38,7 @@ class KstViewLabel : public KstBorderedViewObject {
   Q_PROPERTY(int fontSize READ fontSize WRITE setFontSize)
   Q_PROPERTY(bool transparent READ transparent WRITE setTransparent)
   Q_PROPERTY(int horizontalJustification READ horizJustifyWrap WRITE setHorizJustifyWrap)
+  Q_PROPERTY(int labelMargin READ labelMargin WRITE setLabelMargin)
   public:
     KstViewLabel(const QString& txt = QString::null, KstLJustifyType justify = 0L, float rotation = 0.0);
     KstViewLabel(const QDomElement& e);
@@ -45,6 +46,7 @@ class KstViewLabel : public KstBorderedViewObject {
     ~KstViewLabel();
 
     virtual KstViewObject* copyObjectQuietly(KstViewObject& parent, const QString& name = QString::null) const;
+    virtual KstViewObject* copyObjectQuietly() const;
     void setText(const QString& text);
     const QString& text() const;
 
@@ -86,19 +88,19 @@ class KstViewLabel : public KstBorderedViewObject {
     void paintSelf(KstPainter& p, const QRegion& bounds);
     void resize(const QSize&);
     QRegion clipRegion();
-    void invalidateClipRegion();
 
     void setLabelMargin(int margin);
     int labelMargin() const;
 
     //virtual QMap<QString, QVariant> widgetHints(const QString& propertyName) const;
-    QWidget *configWidget();
+    QWidget *configWidget(QWidget *parent);
 
     // handle custom widget, if any: is called by KstEditViewObjectDialogI
     bool fillConfigWidget(QWidget *w, bool isNew) const;
-    bool readConfigWidget(QWidget *w);
+    bool readConfigWidget(QWidget *w, bool editMultipleMode);
     void connectConfigWidget(QWidget *parent, QWidget *w) const;
-    
+    void populateEditMultiple(QWidget *w);
+
     KstObject::UpdateType update(int counter);
     void adjustSizeForText(const QRect& w);
     QSize sizeForText(const QRect& w);
@@ -130,7 +132,6 @@ class KstViewLabel : public KstBorderedViewObject {
     KstLJustifyType _justify;
     KstBackBuffer _backBuffer;
     Label::Parsed *_parsed;
-    QRegion _myClipMask;
     int _labelMargin;
 
     struct DataCache {
@@ -151,4 +152,4 @@ typedef KstSharedPtr<KstViewLabel> KstViewLabelPtr;
 typedef KstObjectList<KstSharedPtr<KstViewLabel> > KstViewLabelList;
 
 #endif
-// vim: ts=2 sw=2 et
+
