@@ -189,7 +189,7 @@ bool KstViewObjectItem::acceptDrop(const QMimeSource *mime) const {
   if (retVal) {
     _vm->ViewView->viewport()->setCursor(Qt::ArrowCursor);
   } else {
-    _vm->ViewView->viewport()->setCursor(Qt::ForbiddenCursor);  
+    _vm->ViewView->viewport()->setCursor(Qt::ForbiddenCursor);
   }
 
   return retVal;
@@ -201,7 +201,7 @@ void KstViewObjectItem::dropped(QDropEvent *e) {
   if (rtti() == RTTI_OBJ_WINDOW) {
     KstViewWindow *win;
 
-    viewObject(&win);    
+    viewObject(&win);
     if (win) {
       win->view()->widget()->dropped(e);
       accepted = true;
@@ -295,7 +295,7 @@ KstViewObjectPtr KstViewObjectItem::viewObject(KstViewWindow **win) const {
 
   if (rtti() == RTTI_OBJ_WINDOW) {
     *win = dynamic_cast<KstViewWindow*>(KstApp::inst()->findWindow(tagName()));
-    viewObj = (*win)->view()->findChild(tagName(), true);      
+    viewObj = (*win)->view()->findChild(tagName(), true);
   } else {
     item = parent();
     if (item) {
@@ -520,16 +520,16 @@ void KstViewManagerI::edit_I() {
   KstViewObjectItem *koi = static_cast<KstViewObjectItem*>(qi);
   KstViewWindow *win;
 
-  if (koi) {  
+  if (koi) {
     if (qi->rtti() == RTTI_OBJ_WINDOW) {
       win = dynamic_cast<KstViewWindow*>(KstApp::inst()->findWindow(koi->tagName()));
       if (win) {
-        KstApp::inst()->renameWindow(win);
+        win->view()->showDialog(win->view(), false);
       }
     } else if (qi->rtti() == RTTI_OBJ_VIEW_OBJECT) {
       KstViewObjectPtr obj = koi->viewObject(&win);
       if (obj && win) {
-        obj->showDialog(win->view(), false);  
+        obj->showDialog(win->view(), false);
       }
     } else if (qi->rtti() == RTTI_OBJ_DATA_OBJECT) {
       Kst2DPlotPtr plot;
@@ -543,6 +543,23 @@ void KstViewManagerI::edit_I() {
   }
 }
 
+void KstViewManagerI::rename_I() {
+  QListViewItem *qi = ViewView->selectedItem();
+  KstViewObjectItem *koi = static_cast<KstViewObjectItem*>(qi);
+  KstViewWindow *win;
+
+  if (koi) {
+    if (qi->rtti() == RTTI_OBJ_WINDOW) {
+      win = dynamic_cast<KstViewWindow*>(KstApp::inst()->findWindow(koi->tagName()));
+      if (win) {
+        KstApp::inst()->renameWindow(win);
+      }
+    }
+  } else {
+    KMessageBox::sorry(this, i18n("An item must be selected to edit."));
+  }
+}
+
 void KstViewManagerI::delete_I() {
   QListViewItem *qi = ViewView->selectedItem();
   KstViewObjectItem *koi = static_cast<KstViewObjectItem*>(qi);
@@ -711,7 +728,8 @@ void KstViewManagerI::contextMenu(QListViewItem *i, const QPoint& p, int col) {
     menu->insertTitle(koi->text(0));
 
     if (koi->rtti() == RTTI_OBJ_WINDOW) {
-      id = menu->insertItem(i18n("&Rename..."), this, SLOT(edit_I()));
+      id = menu->insertItem(i18n("&Edit..."), this, SLOT(edit_I()));
+      id = menu->insertItem(i18n("&Rename..."), this, SLOT(rename_I()));
       id = menu->insertItem(i18n("&Close"), this, SLOT(delete_I()));
       id = menu->insertItem(i18n("&Activate"), this, SLOT(activate_I()));
 
