@@ -34,8 +34,9 @@ class KstViewMatricesDialogI : public KstViewMatricesDialog {
 
   public slots:
     void updateViewMatricesDialog();
-    void updateViewMatricesDialog(const QString& strVector);
+    void updateViewMatricesDialog(const QString& strMatrix);
     void showViewMatricesDialog();
+    void showViewMatricesDialog(const QString& strMatrix);
     void updateDefaults(int index = 0);
 
   protected slots:
