@@ -102,6 +102,21 @@ void KstViewVectorsDialogI::showViewVectorsDialog() {
 }
 
 
+void KstViewVectorsDialogI::showViewVectorsDialog(const QString &vectorName) {
+  updateViewVectorsDialog();
+
+  KST::vectorList.lock().readLock();
+  KstVectorPtr vector = *KST::vectorList.findTag(vectorName);
+  KST::vectorList.lock().unlock();
+  if (vector) {
+    vectorSelector->setSelection(vector);
+    updateViewVectorsDialog();
+    show();
+    raise();
+  }
+}
+
+
 void KstViewVectorsDialogI::vectorChanged(const QString& vector) {
   updateViewVectorsDialog(vector);
   tableVectors->setVector(vector);
