@@ -55,7 +55,7 @@ KTimezoneCombo::KTimezoneCombo(QWidget *parent, const char *name, KstTimezones *
   int i = 0;
 
   for (KstTimezones::ZoneMap::ConstIterator it = zones.begin(); it != zones.end(); ++it) {
-    int offset = (*it)->offset();
+    int offset = -(*it)->offset();
     d->_offsets[++i] = offset;
     int hours = offset / 3600;
     int minutes = 100 * offset / 3600 % 100;
