@@ -64,7 +64,6 @@ bool collectObjects(Label::Parsed *lp, KstVectorMap& vm, KstScalarMap& scm, KstS
       continue;
     }
 
-//    kstdWarning() << "Label references unknown object [" << fi->text << "]." << endl;
     return false;
   }
 
@@ -135,7 +134,6 @@ QString labelText(QString txt, Label::Parsed *lp, KstVectorMap& vm, KstScalarMap
 
 
 void renderLabel(RenderContext& rc, Label::Chunk *fi, const KstVectorMap& vm, const KstScalarMap& scm, const KstStringMap& stm) {
-  // FIXME: RTL support
   int oldSize = rc.size;
   int oldY = rc.y;
   int oldX = rc.x;
@@ -250,6 +248,7 @@ void renderLabel(RenderContext& rc, Label::Chunk *fi, const KstVectorMap& vm, co
                       if (-rc.y - rc.fontDescent() < 0) {
                         rc.descent = kMax(rc.descent, rc.fontDescent() + rc.y);
                       }
+                      rc.lineSpacing = rc.ascent + rc.descent;
                     }
                     rc.x   += rc.fontWidth(txt);
                     rc.xMax = kMax(rc.xMax, rc.x);
@@ -333,6 +332,7 @@ void renderLabel(RenderContext& rc, Label::Chunk *fi, const KstVectorMap& vm, co
       if (-rc.y - rc.fontDescent() < 0) {
         rc.descent = kMax(rc.descent, rc.fontDescent() + rc.y);
       }
+      rc.lineSpacing = rc.ascent + rc.descent;
     }
 
     int xNext = rc.x;
