@@ -41,6 +41,7 @@ class UpdateThread : public QThread {
     void setFinished(bool finished);
     void setUpdateTime(int updateTime);
     void forceUpdate();
+    void waitForUpdate();
 
   protected:
     virtual void run();
@@ -48,11 +49,14 @@ class UpdateThread : public QThread {
     bool doUpdates(bool force = false, bool *gotData = 0L);
 
   private:
-    bool _paused, _done;
-    bool _force;
     KstWaitCondition _waitCondition;
     mutable QMutex _statusMutex;
     KstDoc *_doc;
+    bool _updateImmediate;
+    bool _updateRunning;
+    bool _paused;
+    bool _done;
+    bool _force;
     int _updateCounter;
     int _updateTime;
     QValueList<KstBaseCurve*> _updatedCurves; // HACK: temporary use in update reworking
