@@ -224,29 +224,29 @@ KstObject::UpdateType KstBasicPlugin::update(int updateCounter) {
     return lastUpdateResult();
   }
 
-  //Make sure we have all the necessary inputs
   if (!inputsExist()) {
     return setLastUpdateResult(NO_CHANGE);
   }
 
+  bool depUpdated;
+
   writeLockInputsAndOutputs();
+  depUpdated = updateInput(updateCounter, force);
 
-  //Update the dependent inputs
-  bool depUpdated = updateInput(updateCounter, force);
+  //
+  // only if one or more inputs has been updated do we want to 
+  // call the plugins algorithm to operate on the inputs and produce the outputs
+  //
+  if (depUpdated) {
+    if (!algorithm()) {
+      KstDebug::self()->log(i18n("There is an error in the %1 algorithm.").arg(propertyString()), KstDebug::Error);
+      unlockInputsAndOutputs();
+      return lastUpdateResult();
+    }
 
-  //Call the plugins algorithm to operate on the inputs
-  //and produce the outputs
-  if ( !algorithm() ) {
-    KstDebug::self()->log(i18n("There is an error in the %1 algorithm.").arg(propertyString()), KstDebug::Error);
-    unlockInputsAndOutputs();
-    return lastUpdateResult();
+    updateOutput(updateCounter);
+    createFitScalars();
   }
-
-  //Perform update on the outputs
-  updateOutput(updateCounter);
-
-  createFitScalars();
-
   unlockInputsAndOutputs();
 
   return setLastUpdateResult(depUpdated ? UPDATE : NO_CHANGE);
@@ -491,7 +491,7 @@ bool KstBasicPlugin::inputsExist() const {
 bool KstBasicPlugin::updateInput(int updateCounter, bool force) const {
   bool depUpdated = force;
 
-  //First, update the inputVectors...
+  // first, update the inputVectors...
   QStringList iv = inputVectorList();
   QStringList::ConstIterator ivI = iv.begin();
   for (; ivI != iv.end(); ++ivI) {
@@ -499,7 +499,7 @@ bool KstBasicPlugin::updateInput(int updateCounter, bool force) const {
     depUpdated = UPDATE == inputVector(*ivI)->update(updateCounter) || depUpdated;
   }
 
-  //Now, update the inputScalars...
+  // now, update the inputScalars...
   QStringList is = inputScalarList();
   QStringList::ConstIterator isI = is.begin();
   for (; isI != is.end(); ++isI) {
@@ -507,7 +507,7 @@ bool KstBasicPlugin::updateInput(int updateCounter, bool force) const {
     depUpdated = UPDATE == inputScalar(*isI)->update(updateCounter) || depUpdated;
   }
 
-  //Finally, update the inputStrings...
+  // finally, update the inputStrings...
   QStringList istr = inputStringList();
   QStringList::ConstIterator istrI = istr.begin();
   for (; istrI != istr.end(); ++istrI) {
