@@ -1,5 +1,5 @@
 /***************************************************************************
-                                kstplugin.cpp
+                                kstcplugin.cpp
                              -------------------
     begin                : May 15 2003
     copyright            : (C) 2003 The University of Toronto
@@ -28,6 +28,7 @@
 // application specific includes
 #include "dialoglauncher.h"
 #include "kstdatacollection.h"
+#include "kstdataobjectcollection.h"
 #include "kstdebug.h"
 #include "kstcplugin.h"
 #include "plugincollection.h"
@@ -158,14 +159,14 @@ void KstCPlugin::commonConstructor() {
   _outStrings = 0L;
 
   _inScalarCnt = 0;
-  _outScalarCnt = 0;
+  _inStringCnt = 0;
   _inArrayCnt = 0;
+  _outScalarCnt = 0;
   _outArrayCnt = 0;
   _typeString = i18n("Plugin");
   _type = "Plugin";
   _plugin = 0L;
   _localData = 0L;
-  //kstdDebug() << "Creating KSTPlugin: " << long(this) << endl;
 }
 
 
@@ -177,7 +178,6 @@ KstCPlugin::~KstCPlugin() {
     }
     _localData = 0L;
   }
-  //kstdDebug() << "Destroying KSTPlugin: " << long(this) << endl;
 }
 
 
@@ -291,9 +291,7 @@ KstObject::UpdateType KstCPlugin::update(int update_counter) {
   bool doUpdate = force;
 
   // Populate the input scalars and vectors
-  for (QValueList<Plugin::Data::IOValue>::ConstIterator it = itable.begin();
-                                                         it != itable.end();
-                                                                        ++it) {
+  for (QValueList<Plugin::Data::IOValue>::ConstIterator it = itable.begin(); it != itable.end(); ++it) {
     if ((*it)._type == Plugin::Data::IOValue::TableType) {
       if (!_inputVectors.contains((*it)._name)) {
         KstDebug::self()->log(i18n("Input vector [%1] for plugin %2 not found.  Unable to continue.").arg((*it)._name).arg(tagName()), KstDebug::Error);
@@ -449,14 +447,14 @@ KstObject::UpdateType KstCPlugin::update(int update_counter) {
 
 QString KstCPlugin::label(int precision) const {
   QString label;
-  
+
   label = i18n("%1: %2").arg(plugin()->data()._readableName).arg(tagName());
   if ((outputVectors())["Parameters"]) {
     QString strParamName;
     QString strValue;
     int length = (outputVectors())["Parameters"]->length();
     int i = 0;
-    
+
     for (strParamName = plugin()->parameterName(0); 
         !strParamName.isEmpty() && i < length; 
         strParamName = plugin()->parameterName(++i)) {
@@ -524,10 +522,16 @@ bool KstCPlugin::slaveVectorsUsed() const {
 
 
 bool KstCPlugin::isValid() const {
-  return _inputVectors.count() == _inArrayCnt &&
+  bool rc = false;
+
+  if (_inArrayCnt > 0 || _inScalarCnt > 0 || _inStringCnt > 0) {
+    rc = _inputVectors.count() == _inArrayCnt &&
          _inputScalars.count() == _inScalarCnt - _inPid &&
          _inputStrings.count() == _inStringCnt &&
          _plugin.data() != 0L;
+  }
+
+  return rc;
 }
 
 
@@ -546,8 +550,108 @@ QString KstCPlugin::propertyString() const {
   return str;
 }
 
+//
+// to be used only from javaScript...
+//
+bool KstCPlugin::validate( ) {
+  bool rc = false;
 
-bool KstCPlugin::setPlugin(KstSharedPtr<Plugin> plugin) {
+  if (_plugin) {
+    if (_plugin.data()) {
+      Plugin::countScalarsVectorsAndStrings(_plugin->data()._inputs, _inScalarCnt, _inArrayCnt, _inStringCnt, _inPid);
+      if (_inArrayCnt > 0 || _inScalarCnt > 0 || _inStringCnt > 0) {
+        if (_inputVectors.count() == _inArrayCnt &&
+          _inputScalars.count() == _inScalarCnt - _inPid &&
+          _inputStrings.count() == _inStringCnt) {
+
+          _outScalarCnt = 0;
+          _outArrayCnt = 0;
+          _outStringCnt = 0;
+          _outputVectors.clear();
+          _outputScalars.clear();
+          _outputStrings.clear();
+
+          freeParameters();
+
+          const QValueList<Plugin::Data::IOValue>& otable = _plugin->data()._outputs;
+          for (QValueList<Plugin::Data::IOValue>::ConstIterator it = otable.begin(); it != otable.end(); ++it) {
+            if ((*it)._type == Plugin::Data::IOValue::TableType) {
+              KstWriteLocker blockVectorUpdates(&KST::vectorList.lock());
+              KstVectorPtr v;
+
+              if ((*it)._subType == Plugin::Data::IOValue::FloatNonVectorSubType) {
+                v = new KstVector(KstObjectTag((*it)._name, tag()), 0, this, true);
+              } else {
+                v = new KstVector(KstObjectTag((*it)._name, tag()), 0, this, false);
+              }
+              _outputVectors.insert((*it)._name, v);
+              ++_outArrayCnt;
+            } else if ((*it)._type == Plugin::Data::IOValue::FloatType) {
+              KstWriteLocker blockScalarUpdates(&KST::scalarList.lock());
+              KstScalarPtr s = new KstScalar(KstObjectTag((*it)._name, tag()), this);
+              _outputScalars.insert((*it)._name, s);
+              ++_outScalarCnt;
+            } else if ((*it)._type == Plugin::Data::IOValue::StringType) {
+              KstWriteLocker blockStringUpdates(&KST::stringList.lock());
+              KstStringPtr s = new KstString(KstObjectTag((*it)._name, tag()), this);
+              _outputStrings.insert((*it)._name, s);
+              ++_outStringCnt;
+            }
+          }
+
+          allocateParameters();
+
+          KstDataObjectList::Iterator oi = KST::dataObjectList.findTag(tagName());
+          if (oi == KST::dataObjectList.end()) {
+            KST::dataObjectList.lock().writeLock();
+            KST::dataObjectList.append(this);
+            KST::dataObjectList.lock().unlock();
+          }
+
+          setDirty(true);
+
+          rc = true;
+        }
+      }
+    }
+  }
+
+  return rc;
+}
+
+
+//
+// to be used only from javaScript...
+//
+bool KstCPlugin::setModule(KstPluginPtr plugin) {
+  // Assumes that this is called with a write lock in place on this object
+  Q_ASSERT(myLockStatus() == KstRWLock::WRITELOCKED);
+
+  if (plugin != _plugin) {
+    freeParameters();
+
+    if (_localData) {
+      if (!_plugin || !_plugin->freeLocalData(&_localData)) {
+        free(_localData);
+      }
+      _localData = 0L;
+    }
+
+    _inputVectors.clear();
+    _inputScalars.clear();
+    _inputStrings.clear();
+    _outputVectors.clear();
+    _outputScalars.clear();
+    _outputStrings.clear();
+
+    _plugin = plugin;
+  }
+
+  return true;
+}
+
+
+bool KstCPlugin::setPlugin(KstPluginPtr plugin) {
   // Assumes that this is called with a write lock in place on this object
   Q_ASSERT(myLockStatus() == KstRWLock::WRITELOCKED);
 
@@ -592,9 +696,7 @@ bool KstCPlugin::setPlugin(KstSharedPtr<Plugin> plugin) {
   _outputStrings.clear();
 
   const QValueList<Plugin::Data::IOValue>& otable = plugin->data()._outputs;
-  for (QValueList<Plugin::Data::IOValue>::ConstIterator it = otable.begin();
-                                                         it != otable.end();
-                                                                        ++it) {
+  for (QValueList<Plugin::Data::IOValue>::ConstIterator it = otable.begin(); it != otable.end(); ++it) {
     if ((*it)._type == Plugin::Data::IOValue::TableType) {
       KstWriteLocker blockVectorUpdates(&KST::vectorList.lock());
       KstVectorPtr v;
@@ -626,7 +728,7 @@ bool KstCPlugin::setPlugin(KstSharedPtr<Plugin> plugin) {
 }
 
 
-KstSharedPtr<Plugin> KstCPlugin::plugin() const {
+KstPluginPtr KstCPlugin::plugin() const {
   return _plugin;
 }
 
@@ -674,7 +776,6 @@ KstDataObject::Kind KstCPlugin::kind() const {
 }
 
 
-// FIXME: KstCPlugin should not know about fit scalars!!
 void KstCPlugin::createFitScalars() {
   Q_ASSERT(myLockStatus() == KstRWLock::WRITELOCKED);
   // Assumes that this is called with a write lock in place on this object
@@ -720,7 +821,7 @@ KstDataObjectPtr KstCPlugin::makeDuplicate(KstDataObjectDataObjectMap& duplicate
   for (KstStringMap::ConstIterator iter = _inputStrings.begin(); iter != _inputStrings.end(); ++iter) {
     plugin->inputStrings().insert(iter.key(), iter.data());  
   }
-  
+
   // create new outputs
   for (KstVectorMap::ConstIterator iter = outputVectors().begin(); iter != outputVectors().end(); ++iter) {
     KstWriteLocker blockVectorUpdates(&KST::vectorList.lock());
@@ -735,7 +836,7 @@ KstDataObjectPtr KstCPlugin::makeDuplicate(KstDataObjectDataObjectMap& duplicate
     KstStringPtr s = new KstString(KstObjectTag(iter.data()->tag().tag() + "'", iter.data()->tag().context()), plugin.data()); // FIXME: unique tag generation
     plugin->outputStrings().insert(iter.key(), s);
   }
-  
+
   // set the same plugin
   plugin->setPlugin(_plugin);
   plugin->setTagName(KstObjectTag(tag().tag() + "'", tag().context())); // FIXME: unique tag generation method
@@ -743,4 +844,28 @@ KstDataObjectPtr KstCPlugin::makeDuplicate(KstDataObjectDataObjectMap& duplicate
   return KstDataObjectPtr(plugin);
 }
 
-// vim: ts=2 sw=2 et
+
+void KstCPlugin::setTagName(const KstObjectTag& tag) {
+  KstObject::setTagName(tag);
+}
+
+
+void KstCPlugin::setTagName(const QString &in_tag) {
+  KstObjectTag newTag(in_tag, tag().context());
+
+  if (newTag == tag()) {
+    return;
+  }
+
+  KstObject::setTagName(newTag);
+
+  for (KstVectorMap::Iterator iter = outputVectors().begin(); iter != outputVectors().end(); ++iter) {
+    (*iter)->setTagName(KstObjectTag(iter.data()->tag().tag(), tag()));
+  }
+  for (KstScalarMap::Iterator iter = outputScalars().begin(); iter != outputScalars().end(); ++iter) {
+    (*iter)->setTagName(KstObjectTag(iter.data()->tag().tag(), tag()));
+  }
+  for (KstStringMap::Iterator iter = outputStrings().begin(); iter != outputStrings().end(); ++iter) {
+    (*iter)->setTagName(KstObjectTag(iter.data()->tag().tag(), tag()));
+  }
+}
