@@ -52,35 +52,42 @@ KstDataObject::KstDataObject(const QDomElement& e) : KstObject() {
 
 
 KstDataObject::~KstDataObject() {
-  // remove our slave vectors, scalars, and strings, and matrices
-  KST::stringList.lock().writeLock();
-  for (KstStringMap::Iterator it = _outputStrings.begin();
-                               it != _outputStrings.end(); ++it) {
-    KST::stringList.remove(it.data());
-  }
-  KST::stringList.lock().unlock();
 
-  KST::scalarList.lock().writeLock();
-  for (KstScalarMap::Iterator it = _outputScalars.begin();
-                               it != _outputScalars.end(); ++it) {
-    KST::scalarList.remove(it.data());
-  }
-  KST::scalarList.lock().unlock();
+  //
+  // remove our slave strings, scalars, vectors, and matrices
+  //
 
-  KST::vectorList.lock().writeLock();
-  for (KstVectorMap::Iterator it = _outputVectors.begin();
-                               it != _outputVectors.end(); ++it) {
-    KST::vectorList.remove(it.data());
+  if (!_outputStrings.isEmpty()) {
+    KST::stringList.lock().writeLock();
+    for (KstStringMap::Iterator it = _outputStrings.begin(); it != _outputStrings.end(); ++it) {
+      KST::stringList.remove(it.data());
+    }
+    KST::stringList.lock().unlock();
   }
-  KST::vectorList.lock().unlock();
 
-  KST::matrixList.lock().writeLock();
-  for (KstMatrixMap::Iterator it = _outputMatrices.begin();
-       it != _outputMatrices.end();
-       ++it) {
-    KST::matrixList.remove(it.data());
+  if (!_outputScalars.isEmpty()) {
+    KST::scalarList.lock().writeLock();
+    for (KstScalarMap::Iterator it = _outputScalars.begin(); it != _outputScalars.end(); ++it) {
+      KST::scalarList.remove(it.data());
+    }
+    KST::scalarList.lock().unlock();
+  }
+
+  if (!_outputVectors.isEmpty()) {
+    KST::vectorList.lock().writeLock();
+    for (KstVectorMap::Iterator it = _outputVectors.begin(); it != _outputVectors.end(); ++it) {
+      KST::vectorList.remove(it.data());
+    }
+    KST::vectorList.lock().unlock();
+  }
+
+  if (!_outputMatrices.isEmpty()) {
+    KST::matrixList.lock().writeLock();
+    for (KstMatrixMap::Iterator it = _outputMatrices.begin(); it != _outputMatrices.end(); ++it) {
+      KST::matrixList.remove(it.data());
+    }
+    KST::matrixList.lock().unlock();
   }
-  KST::matrixList.lock().unlock();
 
   delete _curveHints;
 }
