@@ -156,12 +156,16 @@ void KstEquation::commonConstructor(const QString& in_tag, const QString& in_equ
 
   KstObject::setTagName(KstObjectTag::fromString(tagName));
 
+  writeLock();
+
   KstVectorPtr xv = new KstVector(KstObjectTag("xsv", tag()), 2, this);
   _xOutVector = _outputVectors.insert(XOUTVECTOR, xv);
 
   KstVectorPtr yv = new KstVector(KstObjectTag("sv", tag()), 2, this);
   _yOutVector = _outputVectors.insert(YOUTVECTOR, yv);
 
+  unlock();
+
   _isValid = false;
   _numNew = _numShifted = 0;
 
@@ -308,12 +312,12 @@ void KstEquation::save(QTextStream &ts, const QString& indent) {
 
 
 void KstEquation::setEquation(const QString& in_fn) {
-  // assert(*_xVector); - ugly, we have to allow this here due to
-  // document loading with vector lazy-loading
   setDirty();
   _equation = in_fn;
   setRecursed(false);
 
+  writeLock();
+
   _vectorsUsed.clear();
   _scalarsUsed.clear();
 
@@ -357,6 +361,8 @@ void KstEquation::setEquation(const QString& in_fn) {
     }
   }
   _isValid = _pe != 0L;
+
+  unlock();
 }
 
 
