@@ -877,7 +877,9 @@ void KstImage::yRange(double xFrom, double xTo, double* yMin, double* yMax) {
 }
 
 
-void KstImage::paintLegendSymbol(KstPainter *p, const QRect& bound) {
+void KstImage::paintLegendSymbol(KstPainter *p, const QRect& bound, int scaleWidth) {
+  Q_UNUSED(scaleWidth)
+
   if (hasColorMap() && _pal) {
     int l = bound.left(), r = bound.right(), t = bound.top(), b = bound.bottom();
 
