@@ -371,6 +371,13 @@ QString KstPSD::vTag() const {
 }
 
 
+KstVectorPtr KstPSD::vector() {
+  Q_ASSERT(myLockStatus() == KstRWLock::READLOCKED);
+
+  return _inputVectors[INVECTOR];
+}
+
+
 void KstPSD::setVector(KstVectorPtr new_v) {
   Q_ASSERT(myLockStatus() == KstRWLock::WRITELOCKED);
 
