@@ -955,6 +955,8 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
   }
 
   KstPainter *p = context.p;
+  KstReadLocker xvLocker(xv);
+  KstReadLocker yvLocker(yv);
   QColor foregroundColor = context.foregroundColor;
   double Lx = context.Lx;
   double Hx = context.Hx;
@@ -1322,6 +1324,19 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
     KstVectorPtr exmv = *_inputVectors.find(EXMINUSVECTOR);
     KstVectorPtr eymv = *_inputVectors.find(EYMINUSVECTOR);
 
+    if (exv) {
+      exv->readLock();
+    }
+    if (eyv) {
+      eyv->readLock();
+    }
+    if (exmv) {
+      exmv->readLock();
+    }
+    if (eymv) {
+      eymv->readLock();
+    }
+
     // draw the bargraph bars, if any...
     if (hasBars()) {
       bool has_top = true;
@@ -1708,8 +1723,22 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
         }
       }
     } // end if (hasYError())
+
+    if (exv) {
+      exv->unlock();
+    }
+    if (eyv) {
+      eyv->unlock();
+    }
+    if (exmv) {
+      exmv->unlock();
+    }
+    if (eymv) {
+      eymv->unlock();
+    }
   } // end if (sampleCount() > 0)
 
+
 #ifdef BENCHMARK
   benchmark3 = benchtmp.elapsed();
 #endif
@@ -2036,13 +2065,17 @@ double KstVCurve::distanceToPoint(double xpos, double ypos, double distanceMax,
 }
 
 
-void KstVCurve::paintLegendSymbol(KstPainter *p, const QRect& bound) {
+void KstVCurve::paintLegendSymbol(KstPainter *p, const QRect& bound, int scaleWidth) {
   int width;
 
+  if (scaleWidth < 1) {
+    scaleWidth = 1;
+  }
+
   if (lineWidth() == 0) {
-    width = p->lineWidthAdjustmentFactor();
+    width = p->lineWidthAdjustmentFactor() * scaleWidth;
   } else {
-    width = lineWidth() * p->lineWidthAdjustmentFactor();
+    width = lineWidth() * p->lineWidthAdjustmentFactor() * scaleWidth;
   }
 
   p->save();
