@@ -237,6 +237,10 @@ inline bool parseOutChar(const QString& txt, uint from, int *skip, Chunk **tail,
         *skip = 3;
         setNormalChar(QChar(0x397+x), tail);
         return true;
+      } else if (txt.mid(from + 1).startsWith("ll")) {
+        *skip = 3;
+        setNormalChar(QChar(0x2113), tail);
+        return true;
       }
       break;
 
@@ -331,6 +335,10 @@ inline bool parseOutChar(const QString& txt, uint from, int *skip, Chunk **tail,
         *skip = 5;
         setNormalChar(QChar(0x3A9+x), tail);
         return true;
+      } else if (txt.mid(from + 1).startsWith("dot")) {
+        *skip = 4;
+        setNormalChar(QChar(0x2299), tail);
+        return true;
       }
       break;
 
