@@ -74,6 +74,16 @@ BinnedMapDialogI::~BinnedMapDialogI() {
 }
 
 
+QString BinnedMapDialogI::editTitle() {
+  return i18n("Edit Binned Map");
+}
+
+
+QString BinnedMapDialogI::newTitle() {
+  return i18n("New Binned Map");
+}
+
+
 void BinnedMapDialogI::update() {
   _w->_X->update();
   _w->_Y->update();
@@ -255,7 +265,7 @@ void BinnedMapDialogI::fillAutoRange() {
   KstVectorPtr vy = *KST::vectorList.findTag(_w->_Y->selectedVector());
 
   if (vx && vy) {
-    BinnedMap::AutoSize(vx, vy, &nx, &minx, &maxx, &ny, &miny, &maxy);
+    BinnedMap::autoSize(vx, vy, &nx, &minx, &maxx, &ny, &miny, &maxy);
 
     _w->_Xmin->setText(QString::number(minx));
     _w->_Xmax->setText(QString::number(maxx));
