@@ -39,6 +39,8 @@ class KST_EXPORT CrossSpectrumDialogI : public KstDataDialog {
   protected:
     virtual void fillFieldsForEdit();
     virtual void fillFieldsForNew();
+    QString editTitle();
+    QString newTitle();
 
   private:
     bool editSingleObject(CrossPowerSpectrumPtr cps);
