@@ -228,9 +228,13 @@ void doTests() {
 
 
 int main(int argc, char **argv) {
+  Q_UNUSED(argc);
+  Q_UNUSED(argv);
+
   atexit(exitHelper);
 
-  KApplication app(argc, argv, "testcsd", false, false);
+  KCmdLineArgs::init(argc, argv, "testcsd", "testcsd", "testcsd", "1.0.0.0");
+  KApplication app(false, false);
 
   doTests();
   // Don't put tests in main because we need to ensure that no KstObjects
