@@ -86,7 +86,13 @@ bool doTest(const char *equation, double x, double result, const double tol = 0.
     KstScalarMap scm;
     KstStringMap stm;
     eq->collectObjects(vectorsUsed, scm, stm);
-    eq->update(-1, &ctx);
+
+    //
+    // do not use -1 in the call to eq->update( ... ) 
+    //  as this will simply return without updating the plugin,
+    //  unless an underlying data object was updated...
+    //
+    eq->update(0, &ctx);
     double v = eq->value(&ctx);
     delete eq;
     if (fabs(v - result) < tol || (result != result && v != v) || (result == INF && v == INF) || (result == -INF && v == -INF)) {
@@ -210,9 +216,13 @@ static void exitHelper() {
 extern int yydebug;
 
 int main(int argc, char **argv) {
+  Q_UNUSED(argc);
+  Q_UNUSED(argv);
+
   atexit(exitHelper);
 
-  KApplication app(argc, argv, "testeqparser", false, false);
+  KCmdLineArgs::init(argc, argv, "testeqparser", "testeqparser", "testeqparser", "1.0.0.0");
+  KApplication app(false, false);
 
   // Numbers
   test("0", 1.0, 0.0);
@@ -424,7 +434,7 @@ int main(int argc, char **argv) {
   test("[sdf]", 0.0, NOPOINT);
 
   test("[=10+10]", 0.0, 20.0);
-  
+
   // Vectors
   KstVector::generateVector(0, 1.0, 10, KstObjectTag("1"));
   KstVector::generateVector(0, 1.0, 10, KstObjectTag("V1"));
@@ -440,14 +450,12 @@ int main(int argc, char **argv) {
   // TODO: interpolation, more vector combinations
 
   // Plugins
-  test("2*plugin(bin, [V4], 12)", 1.0, -1.9779779779779778);
-  test("4*plugin(bin, [V4], x)", 5.0, -3.9839839839839839);
-  test("-3*plugin(bin, x, 12)", 2.0, NOPOINT);
+  test("2*plugin(Bin, [V4], 12)", 1.0, -1.9779779779779778);
+  test("4*plugin(Bin, [V4], x)", 5.0, -3.9839839839839839);
+  test("-3*plugin(Bin, x, 12)", 2.0, NOPOINT);
   xVector = KstVector::generateVector(0, 100, 2000, KstObjectTag("XVector"));
-  test("-3*plugin(bin, x, 12)", 2.0, -0.8254127063531767);
-  test("-3*plugin(bin, y, 12)", 2.0, NOPOINT);
-
-  // TODO: more plugin tests
+  test("-3*plugin(Bin, x, 12)", 2.0, -0.8254127063531767);
+  test("-3*plugin(Bin, y, 12)", 2.0, NOPOINT);
 
   // TODO: float notation
 
@@ -589,7 +597,7 @@ int main(int argc, char **argv) {
   if (rc == KstTestSuccess) {
     printf("All tests passed!\n");
   }
+
   return -rc;
 }
 
-// vim: ts=2 sw=2 et
