@@ -125,9 +125,13 @@ void doTests() {
 
 
 int main(int argc, char **argv) {
+  Q_UNUSED(argc);
+  Q_UNUSED(argv);
+
   atexit(exitHelper);
 
-  KApplication app(argc, argv, "testhistogram", false, false);
+  KCmdLineArgs::init(argc, argv, "testhistogram", "testhistogram", "testhistogram", "1.0.0.0");
+  KApplication app(false, false);
 
   doTests();
 
